/*====================================================================
* Project:  Board Support Package (BSP)
* Function: Application Processor 0 function
*
* Copyright HighTec EDV-Systeme GmbH 1982-2018
*====================================================================*/

#include <stdlib.h>
#include <machine/intrinsics.h>

#include "system.h"
#include "tc_inc_path.h"

#include TC_INCLUDE(TCPATH/IfxCpu_reg.h)
#include TC_INCLUDE(TCPATH/IfxCbs_reg.h)


/* link to trap table */
/* all cores will use the same trap table */
extern void first_trap_table(void);

extern int main(void);
extern void Start_Core(unsigned int coreId);

int init_applproc0(int argc, char **argv);

/* activate CDC (Core Debug Controller) */
static void enable_cdc(void)
{
	/* check whether CDC is already active */
	if (0 == CBS_OSTATE.B.OEN)
	{
		CBS_OEC.U = 0x100A1;
		CBS_OEC.U = 0x1005E;
		CBS_OEC.U = 0x100A1;
		CBS_OEC.U = 0x1005E;
	}
}


/*!
 * \brief   main_init Function.
 *
 * main_init() will be called after config initialisation
 */
static void main_init(void)
{
	SYSTEM_Init();

	SYSTEM_DisableProtection();
	_dsync();
	/* install trap handlers */
	_mtcr(CPU_BTV, (unsigned int)first_trap_table);
	_isync();

	_mtcr(CPU_PCON0, 0);		/* enable code cache */
	_mtcr(CPU_DCON0, 0);		/* enable data cache */
	_mtcr(CPU_PMA0, 0x3E0);		/* allow data caching for global CPUn memories */
	_mtcr(CPU_PMA1, 0x3E0);		/* allow code caching for global CPUn memories */
	_dsync();
	SYSTEM_EnableProtection();

	/* CDC (Core Debug Controller) must be active for performance counter usage */
	enable_cdc();

	/* activate performance counters */
	/* CE = 1, M1 = PCACHE_HIT, M2 = PCACHE_MISS, M3 = DCACHE_MISS_DIRTY (only TC1.6P) */
	_mtcr(CPU_CCTRL, 0x2 | (0x1 << 2) | (0x1 << 5) | (0x2 << 8));
}



int init_applproc0(int argc, char **argv)
{
	int res = 0;

	(void)argc;
	(void)argv;

	/* hw dependent functions */
	main_init();

	/*
	 * start the other cores
	 */
#if (RUN_ON_16P == 1)
	Start_Core(1);
	while (1)
		;
#elif (RUN_ON_16P == 2)
	Start_Core(2);
	while (1)
		;
#else

	/* all global initialisation done, call the main routine for CPU0 */
	res = main();
#endif /* RUN_ON_16P == 1 */

	return res;
}
