/*====================================================================
* Project:  Board Support Package (BSP)
* Function: Application Processor 1 function
*
* Copyright HighTec EDV-Systeme GmbH 1982-2018
*====================================================================*/

#include <stdlib.h>
#include <machine/intrinsics.h>

#include "system.h"
#include "tc_inc_path.h"

#include TC_INCLUDE(TCPATH/IfxCpu_reg.h)


/* link to trap table */
/* all cores will use the same trap table */
extern void first_trap_table(void);
extern int main(void);

int init_applproc1(int argc, char **argv);

int init_applproc1(int argc, char **argv)
{
	(void)argc;
	(void)argv;

	SYSTEM_DisableProtection();
	_dsync();
	/* install trap handlers */
	_mtcr(CPU_BTV, (unsigned int)first_trap_table);
	_isync();

	_mtcr(CPU_PCON0, 0);		/* enable code cache */
	_mtcr(CPU_DCON0, 0);		/* enable data cache */
	_mtcr(CPU_PMA0, 0x3E0);		/* allow data caching for global CPUn memories */
	_mtcr(CPU_PMA1, 0x3E0);		/* allow code caching for global CPUn memories */
	_dsync();
	SYSTEM_EnableProtection();

	/* activate performance counters */
	/* CE = 1, M1 = PCACHE_HIT, M2 = PCACHE_MISS, M3 = DCACHE_MISS_DIRTY (only TC1.6P) */
	_mtcr(CPU_CCTRL, 0x2 | (0x1 << 2) | (0x1 << 5) | (0x2 << 8));

	main();

	return 0;
}
