/*====================================================================
* Project:  Board Support Package (BSP)
* Function: Interrupt Service Node IDs on TC39xA
*
* Copyright HighTec EDV-Systeme GmbH 1982-2018
*====================================================================*/

#ifndef __INTIDS_TC39XA_H__
#define __INTIDS_TC39XA_H__

/* Interrupt SRC IDs */
#define SRC_ID_CPU0SB			0	/* CPU 0 Software Breakpoint Service Request */
#define SRC_ID_CPU1SB			1	/* CPU 1 Software Breakpoint Service Request */
#define SRC_ID_CPU2SB			2	/* CPU 2 Software Breakpoint Service Request */
#define SRC_ID_CPU3SB			3	/* CPU 3 Software Breakpoint Service Request */
#define SRC_ID_CPU4SB			4	/* CPU 4 Software Breakpoint Service Request */
#define SRC_ID_CPU5SB			5	/* CPU 5 Software Breakpoint Service Request */

#define SRC_ID_BCUSPB			8	/* Bus Control Unit SPB Service Request */
#define SRC_ID_BCUBBB			9	/* Bus Control Unit BBB Service Request (ED only) */

#define SRC_ID_AGBT				11	/* AGBT Service Request (ED only) */

#define SRC_ID_XBAR0			12	/* Domain 0 XBAR_SRI Service Request */
#define SRC_ID_XBAR1			13	/* Domain 1 XBAR_SRI Service Request */
#define SRC_ID_XBAR2			14	/* ED Domain XBAR_SRI Service Request (ED only) */

#define SRC_ID_CERBERUS0		16	/* Cerberus Service Request 0 */
#define SRC_ID_CERBERUS1		17	/* Cerberus Service Request 1 */

#define SRC_ID_ASCLIN0TX		20	/* ASCLIN 0 Transmit Service Request */
#define SRC_ID_ASCLIN0RX		21	/* ASCLIN 0 Receive Service Request */
#define SRC_ID_ASCLIN0EX		22	/* ASCLIN 0 Error Service Request */
#define SRC_ID_ASCLIN1TX		23	/* ASCLIN 1 Transmit Service Request */
#define SRC_ID_ASCLIN1RX		24	/* ASCLIN 1 Receive Service Request */
#define SRC_ID_ASCLIN1EX		25	/* ASCLIN 1 Error Service Request */
#define SRC_ID_ASCLIN2TX		26	/* ASCLIN 2 Transmit Service Request */
#define SRC_ID_ASCLIN2RX		27	/* ASCLIN 2 Receive Service Request */
#define SRC_ID_ASCLIN2EX		28	/* ASCLIN 2 Error Service Request */
#define SRC_ID_ASCLIN3TX		29	/* ASCLIN 3 Transmit Service Request */
#define SRC_ID_ASCLIN3RX		30	/* ASCLIN 3 Receive Service Request */
#define SRC_ID_ASCLIN3EX		31	/* ASCLIN 3 Error Service Request */
#define SRC_ID_ASCLIN4TX		32	/* ASCLIN 4 Transmit Service Request */
#define SRC_ID_ASCLIN4RX		33	/* ASCLIN 4 Receive Service Request */
#define SRC_ID_ASCLIN4EX		34	/* ASCLIN 4 Error Service Request */
#define SRC_ID_ASCLIN5TX		35	/* ASCLIN 5 Transmit Service Request */
#define SRC_ID_ASCLIN5RX		36	/* ASCLIN 5 Receive Service Request */
#define SRC_ID_ASCLIN5EX		37	/* ASCLIN 5 Error Service Request */
#define SRC_ID_ASCLIN6TX		38	/* ASCLIN 6 Transmit Service Request */
#define SRC_ID_ASCLIN6RX		39	/* ASCLIN 6 Receive Service Request */
#define SRC_ID_ASCLIN6EX		40	/* ASCLIN 6 Error Service Request */
#define SRC_ID_ASCLIN7TX		41	/* ASCLIN 7 Transmit Service Request */
#define SRC_ID_ASCLIN7RX		42	/* ASCLIN 7 Receive Service Request */
#define SRC_ID_ASCLIN7EX		43	/* ASCLIN 7 Error Service Request */

#define SRC_ID_MTUDONE			47	/* MTU Done Service Request */

#define SRC_ID_QSPI0TX			48	/* QSPI 0 Transmit Service Request */
#define SRC_ID_QSPI0RX			49	/* QSPI 0 Receive Service Request */
#define SRC_ID_QSPI0ERR			50	/* QSPI 0 Error Service Request */
#define SRC_ID_QSPI0PT			51	/* QSPI 0 Phase Transition Service Request */
#define SRC_ID_QSPI0U			52	/* QSPI 0 User Defined Service Request */
#define SRC_ID_QSPI1TX			53	/* QSPI 1 Transmit Service Request */
#define SRC_ID_QSPI1RX			54	/* QSPI 1 Receive Service Request */
#define SRC_ID_QSPI1ERR			55	/* QSPI 1 Error Service Request */
#define SRC_ID_QSPI1PT			56	/* QSPI 1 Phase Transition Service Request */
#define SRC_ID_QSPI1U			57	/* QSPI 1 User Defined Service Request */
#define SRC_ID_QSPI2TX			58	/* QSPI 2 Transmit Service Request */
#define SRC_ID_QSPI2RX			58	/* QSPI 2 Receive Service Request */
#define SRC_ID_QSPI2ERR			60	/* QSPI 2 Error Service Request */
#define SRC_ID_QSPI2PT			61	/* QSPI 2 Phase Transition Service Request */
#define SRC_ID_QSPI2U			62	/* QSPI 2 User Defined Service Request */
#define SRC_ID_QSPI3TX			63	/* QSPI 3 Transmit Service Request */
#define SRC_ID_QSPI3RX			64	/* QSPI 3 Receive Service Request */
#define SRC_ID_QSPI3ERR			65	/* QSPI 3 Error Service Request */
#define SRC_ID_QSPI3PT			66	/* QSPI 3 Phase Transition Service Request */
#define SRC_ID_QSPI3U			67	/* QSPI 3 User Defined Service Request */
#define SRC_ID_QSPI4TX			68	/* QSPI 4 Transmit Service Request */
#define SRC_ID_QSPI4RX			69	/* QSPI 4 Receive Service Request */
#define SRC_ID_QSPI4ERR			70	/* QSPI 4 Error Service Request */
#define SRC_ID_QSPI4PT			71	/* QSPI 4 Phase Transition Service Request */
#define SRC_ID_QSPI4U			72	/* QSPI 4 User Defined Service Request */
#define SRC_ID_QSPI5TX			73	/* QSPI 5 Transmit Service Request */
#define SRC_ID_QSPI5RX			74	/* QSPI 5 Receive Service Request */
#define SRC_ID_QSPI5ERR			75	/* QSPI 5 Error Service Request */
#define SRC_ID_QSPI5PT			76	/* QSPI 5 Phase Transition Service Request */
#define SRC_ID_QSPI5U			77	/* QSPI 5 User Defined Service Request */

#define SRC_ID_QSPI2HC			86	/* QSPI 2 High Speed Capture Service Request */
#define SRC_ID_QSPI3HC			87	/* QSPI 3 High Speed Capture Service Request */

#define SRC_ID_HSCT0			88	/* HSCT0 Service Request */
#define SRC_ID_HSCT1			89	/* HSCT1 Service Request */

#define SRC_ID_HSSL0COK0		92	/* HSSL0 Channel 0 OK Service Request */
#define SRC_ID_HSSL0RDI0		93	/* HSSL0 Channel 0 Read Data Service Request */
#define SRC_ID_HSSL0ERR0		94	/* HSSL0 Channel 0 Error Service Request */
#define SRC_ID_HSSL0TRG0		95	/* HSSL0 Channel 0 Trigger Service Request */
#define SRC_ID_HSSL0COK1		96	/* HSSL0 Channel 1 OK Service Request */
#define SRC_ID_HSSL0RDI1		97	/* HSSL0 Channel 1 Read Data Service Request */
#define SRC_ID_HSSL0ERR1		98	/* HSSL0 Channel 1 Error Service Request */
#define SRC_ID_HSSL0TRG1		99	/* HSSL0 Channel 1 Trigger Service Request */
#define SRC_ID_HSSL0COK2		100	/* HSSL0 Channel 2 OK Service Request */
#define SRC_ID_HSSL0RDI2		101	/* HSSL0 Channel 2 Read Data Service Request */
#define SRC_ID_HSSL0ERR2		102	/* HSSL0 Channel 2 Error Service Request */
#define SRC_ID_HSSL0TRG2		103	/* HSSL0 Channel 2 Trigger Service Request */
#define SRC_ID_HSSL0COK3		104	/* HSSL0 Channel 3 OK Service Request */
#define SRC_ID_HSSL0RDI3		105	/* HSSL0 Channel 3 Read Data Service Request */
#define SRC_ID_HSSL0ERR3		106	/* HSSL0 Channel 3 Error Service Request */
#define SRC_ID_HSSL0TRG3		107	/* HSSL0 Channel 3 Trigger Service Request */
#define SRC_ID_HSSL0EXI			108	/* HSSL0 Exception Service Request */
#define SRC_ID_HSSL1COK0		109	/* HSSL1 Channel 0 OK Service Request */
#define SRC_ID_HSSL1RDI0		110	/* HSSL1 Channel 0 Read Data Service Request */
#define SRC_ID_HSSL1ERR0		111	/* HSSL1 Channel 0 Error Service Request */
#define SRC_ID_HSSL1TRG0		112	/* HSSL1 Channel 0 Trigger Service Request */
#define SRC_ID_HSSL1COK1		113	/* HSSL1 Channel 1 OK Service Request */
#define SRC_ID_HSSL1RDI1		114	/* HSSL1 Channel 1 Read Data Service Request */
#define SRC_ID_HSSL1ERR1		115	/* HSSL1 Channel 1 Error Service Request */
#define SRC_ID_HSSL1TRG1		116	/* HSSL1 Channel 1 Trigger Service Request */
#define SRC_ID_HSSL1COK2		117	/* HSSL1 Channel 2 OK Service Request */
#define SRC_ID_HSSL1RDI2		118	/* HSSL1 Channel 2 Read Data Service Request */
#define SRC_ID_HSSL1ERR2		119	/* HSSL1 Channel 2 Error Service Request */
#define SRC_ID_HSSL1TRG2		120	/* HSSL1 Channel 2 Trigger Service Request */
#define SRC_ID_HSSL1COK3		121	/* HSSL1 Channel 3 OK Service Request */
#define SRC_ID_HSSL1RDI3		122	/* HSSL1 Channel 3 Read Data Service Request */
#define SRC_ID_HSSL1ERR3		123	/* HSSL1 Channel 3 Error Service Request */
#define SRC_ID_HSSL1TRG3		124	/* HSSL1 Channel 3 Trigger Service Request */
#define SRC_ID_HSSL1EXI			125	/* HSSL1 Exception Service Request */

#define SRC_ID_I2C0DTR			128	/* I2C 0 Data Transfer Request */
#define SRC_ID_I2C0ERR			129	/* I2C 0 Error Service Request */
#define SRC_ID_I2C0P			130	/* I2C 0 Protocol Service Request */

#define SRC_ID_I2C1DTR			132	/* I2C 1 Data Transfer Request */
#define SRC_ID_I2C1ERR			133	/* I2C 1 Error Service Request */
#define SRC_ID_I2C1P			134	/* I2C 1 Protocol Service Request */

#define SRC_ID_SENT0			136	/* SENT TRIG0 Service Request */
#define SRC_ID_SENT1			137	/* SENT TRIG1 Service Request */
#define SRC_ID_SENT2			138	/* SENT TRIG2 Service Request */
#define SRC_ID_SENT3			139	/* SENT TRIG3 Service Request */
#define SRC_ID_SENT4			140	/* SENT TRIG4 Service Request */
#define SRC_ID_SENT5			141	/* SENT TRIG5 Service Request */
#define SRC_ID_SENT6			142	/* SENT TRIG6 Service Request */
#define SRC_ID_SENT7			143	/* SENT TRIG7 Service Request */
#define SRC_ID_SENT8			144	/* SENT TRIG8 Service Request */
#define SRC_ID_SENT9			145	/* SENT TRIG9 Service Request */

#define SRC_ID_MSC0SR0			148	/* MSC 0 Service Request 0 */
#define SRC_ID_MSC0SR1			149	/* MSC 0 Service Request 1 */
#define SRC_ID_MSC0SR2			150	/* MSC 0 Service Request 2 */
#define SRC_ID_MSC0SR3			151	/* MSC 0 Service Request 3 */
#define SRC_ID_MSC0SR4			152	/* MSC 0 Service Request 4 */
#define SRC_ID_MSC1SR0			153	/* MSC 1 Service Request 0 */
#define SRC_ID_MSC1SR1			154	/* MSC 1 Service Request 1 */
#define SRC_ID_MSC1SR2			155	/* MSC 1 Service Request 2 */
#define SRC_ID_MSC1SR3			156	/* MSC 1 Service Request 3 */
#define SRC_ID_MSC1SR4			157	/* MSC 1 Service Request 4 */
#define SRC_ID_MSC2SR0			158	/* MSC 2 Service Request 0 */
#define SRC_ID_MSC2SR1			159	/* MSC 2 Service Request 1 */
#define SRC_ID_MSC2SR2			160	/* MSC 2 Service Request 2 */
#define SRC_ID_MSC2SR3			161	/* MSC 2 Service Request 3 */
#define SRC_ID_MSC2SR4			162	/* MSC 2 Service Request 4 */
#define SRC_ID_MSC3SR0			163	/* MSC 3 Service Request 0 */
#define SRC_ID_MSC3SR1			164	/* MSC 3 Service Request 1 */
#define SRC_ID_MSC3SR2			165	/* MSC 3 Service Request 2 */
#define SRC_ID_MSC3SR3			166	/* MSC 3 Service Request 3 */
#define SRC_ID_MSC3SR4			167	/* MSC 3 Service Request 4 */

#define SRC_ID_CCU60SR0			168	/* CCU6 0 Service Request 0 */
#define SRC_ID_CCU60SR1			169	/* CCU6 0 Service Request 1 */
#define SRC_ID_CCU60SR2			170	/* CCU6 0 Service Request 2 */
#define SRC_ID_CCU60SR3			171	/* CCU6 0 Service Request 3 */
#define SRC_ID_CCU61SR0			172	/* CCU6 1 Service Request 0 */
#define SRC_ID_CCU61SR1			173	/* CCU6 1 Service Request 1 */
#define SRC_ID_CCU61SR2			174	/* CCU6 1 Service Request 2 */
#define SRC_ID_CCU61SR3			175	/* CCU6 1 Service Request 3 */

#define SRC_ID_GPT120CIRQ		184	/* GPT120 CAPREL Service Request */
#define SRC_ID_GPT120T2			185	/* GPT120 T2 Overflow/Underflow Service Request */
#define SRC_ID_GPT120T3			186	/* GPT120 T3 Overflow/Underflow Service Request */
#define SRC_ID_GPT120T4			187	/* GPT120 T4 Overflow/Underflow Service Request */
#define SRC_ID_GPT120T5			188	/* GPT120 T5 Overflow/Underflow Service Request */
#define SRC_ID_GPT120T6			189	/* GPT120 T6 Overflow/Underflow Service Request */

#define SRC_ID_STM0SR0			192	/* System Timer 0 Service Request 0 */
#define SRC_ID_STM0SR1			193	/* System Timer 0 Service Request 1 */
#define SRC_ID_STM1SR0			194	/* System Timer 1 Service Request 0 */
#define SRC_ID_STM1SR1			195	/* System Timer 1 Service Request 1 */
#define SRC_ID_STM2SR0			196	/* System Timer 2 Service Request 0 */
#define SRC_ID_STM2SR1			197	/* System Timer 2 Service Request 1 */
#define SRC_ID_STM3SR0			198	/* System Timer 3 Service Request 0 */
#define SRC_ID_STM3SR1			199	/* System Timer 3 Service Request 1 */
#define SRC_ID_STM4SR0			200	/* System Timer 4 Service Request 0 */
#define SRC_ID_STM4SR1			201	/* System Timer 4 Service Request 1 */
#define SRC_ID_STM5SR0			202	/* System Timer 5 Service Request 0 */
#define SRC_ID_STM5SR1			202	/* System Timer 5 Service Request 1 */

#define SRC_ID_FCE0				204	/* FCE0 Error Service Request */

#define SRC_ID_DMAERR			208	/* DMA Error Service Request */

#define SRC_ID_DMACH0			212	/* DMA Channel   0 Service Request */
#define SRC_ID_DMACH1			213	/* DMA Channel   1 Service Request */
#define SRC_ID_DMACH2			214	/* DMA Channel   2 Service Request */
#define SRC_ID_DMACH3			215	/* DMA Channel   3 Service Request */
#define SRC_ID_DMACH4			216	/* DMA Channel   4 Service Request */
#define SRC_ID_DMACH5			217	/* DMA Channel   5 Service Request */
#define SRC_ID_DMACH6			218	/* DMA Channel   6 Service Request */
#define SRC_ID_DMACH7			219	/* DMA Channel   7 Service Request */
#define SRC_ID_DMACH8			220	/* DMA Channel   8 Service Request */
#define SRC_ID_DMACH9			221	/* DMA Channel   9 Service Request */
#define SRC_ID_DMACH10			222	/* DMA Channel  10 Service Request */
#define SRC_ID_DMACH11			223	/* DMA Channel  11 Service Request */
#define SRC_ID_DMACH12			224	/* DMA Channel  12 Service Request */
#define SRC_ID_DMACH13			225	/* DMA Channel  13 Service Request */
#define SRC_ID_DMACH14			226	/* DMA Channel  14 Service Request */
#define SRC_ID_DMACH15			227	/* DMA Channel  15 Service Request */
#define SRC_ID_DMACH16			228	/* DMA Channel  16 Service Request */
#define SRC_ID_DMACH17			229	/* DMA Channel  17 Service Request */
#define SRC_ID_DMACH18			230	/* DMA Channel  18 Service Request */
#define SRC_ID_DMACH19			231	/* DMA Channel  19 Service Request */
#define SRC_ID_DMACH20			232	/* DMA Channel  20 Service Request */
#define SRC_ID_DMACH21			233	/* DMA Channel  21 Service Request */
#define SRC_ID_DMACH22			234	/* DMA Channel  22 Service Request */
#define SRC_ID_DMACH23			235	/* DMA Channel  23 Service Request */
#define SRC_ID_DMACH24			236	/* DMA Channel  24 Service Request */
#define SRC_ID_DMACH25			237	/* DMA Channel  25 Service Request */
#define SRC_ID_DMACH26			238	/* DMA Channel  26 Service Request */
#define SRC_ID_DMACH27			239	/* DMA Channel  27 Service Request */
#define SRC_ID_DMACH28			240	/* DMA Channel  28 Service Request */
#define SRC_ID_DMACH29			241	/* DMA Channel  29 Service Request */
#define SRC_ID_DMACH30			242	/* DMA Channel  30 Service Request */
#define SRC_ID_DMACH31			243	/* DMA Channel  31 Service Request */
#define SRC_ID_DMACH32			244	/* DMA Channel  32 Service Request */
#define SRC_ID_DMACH33			245	/* DMA Channel  33 Service Request */
#define SRC_ID_DMACH34			246	/* DMA Channel  34 Service Request */
#define SRC_ID_DMACH35			247	/* DMA Channel  35 Service Request */
#define SRC_ID_DMACH36			248	/* DMA Channel  36 Service Request */
#define SRC_ID_DMACH37			249	/* DMA Channel  37 Service Request */
#define SRC_ID_DMACH38			250	/* DMA Channel  38 Service Request */
#define SRC_ID_DMACH39			251	/* DMA Channel  39 Service Request */
#define SRC_ID_DMACH40			252	/* DMA Channel  40 Service Request */
#define SRC_ID_DMACH41			253	/* DMA Channel  41 Service Request */
#define SRC_ID_DMACH42			254	/* DMA Channel  42 Service Request */
#define SRC_ID_DMACH43			255	/* DMA Channel  43 Service Request */
#define SRC_ID_DMACH44			256	/* DMA Channel  44 Service Request */
#define SRC_ID_DMACH45			257	/* DMA Channel  45 Service Request */
#define SRC_ID_DMACH46			258	/* DMA Channel  46 Service Request */
#define SRC_ID_DMACH47			259	/* DMA Channel  47 Service Request */
#define SRC_ID_DMACH48			260	/* DMA Channel  48 Service Request */
#define SRC_ID_DMACH49			261	/* DMA Channel  49 Service Request */
#define SRC_ID_DMACH50			262	/* DMA Channel  50 Service Request */
#define SRC_ID_DMACH51			263	/* DMA Channel  51 Service Request */
#define SRC_ID_DMACH52			264	/* DMA Channel  52 Service Request */
#define SRC_ID_DMACH53			265	/* DMA Channel  53 Service Request */
#define SRC_ID_DMACH54			266	/* DMA Channel  54 Service Request */
#define SRC_ID_DMACH55			267	/* DMA Channel  55 Service Request */
#define SRC_ID_DMACH56			268	/* DMA Channel  56 Service Request */
#define SRC_ID_DMACH57			269	/* DMA Channel  57 Service Request */
#define SRC_ID_DMACH58			270	/* DMA Channel  58 Service Request */
#define SRC_ID_DMACH59			271	/* DMA Channel  59 Service Request */
#define SRC_ID_DMACH60			272	/* DMA Channel  60 Service Request */
#define SRC_ID_DMACH61			273	/* DMA Channel  61 Service Request */
#define SRC_ID_DMACH62			274	/* DMA Channel  62 Service Request */
#define SRC_ID_DMACH63			275	/* DMA Channel  63 Service Request */
#define SRC_ID_DMACH64			276	/* DMA Channel  64 Service Request */
#define SRC_ID_DMACH65			277	/* DMA Channel  65 Service Request */
#define SRC_ID_DMACH66			278	/* DMA Channel  66 Service Request */
#define SRC_ID_DMACH67			279	/* DMA Channel  67 Service Request */
#define SRC_ID_DMACH68			280	/* DMA Channel  68 Service Request */
#define SRC_ID_DMACH69			281	/* DMA Channel  69 Service Request */
#define SRC_ID_DMACH70			282	/* DMA Channel  70 Service Request */
#define SRC_ID_DMACH71			283	/* DMA Channel  71 Service Request */
#define SRC_ID_DMACH72			284	/* DMA Channel  72 Service Request */
#define SRC_ID_DMACH73			285	/* DMA Channel  73 Service Request */
#define SRC_ID_DMACH74			286	/* DMA Channel  74 Service Request */
#define SRC_ID_DMACH75			287	/* DMA Channel  75 Service Request */
#define SRC_ID_DMACH76			288	/* DMA Channel  76 Service Request */
#define SRC_ID_DMACH77			289	/* DMA Channel  77 Service Request */
#define SRC_ID_DMACH78			290	/* DMA Channel  78 Service Request */
#define SRC_ID_DMACH79			291	/* DMA Channel  79 Service Request */
#define SRC_ID_DMACH80			292	/* DMA Channel  80 Service Request */
#define SRC_ID_DMACH81			293	/* DMA Channel  81 Service Request */
#define SRC_ID_DMACH82			294	/* DMA Channel  82 Service Request */
#define SRC_ID_DMACH83			295	/* DMA Channel  83 Service Request */
#define SRC_ID_DMACH84			296	/* DMA Channel  84 Service Request */
#define SRC_ID_DMACH85			297	/* DMA Channel  85 Service Request */
#define SRC_ID_DMACH86			298	/* DMA Channel  86 Service Request */
#define SRC_ID_DMACH87			299	/* DMA Channel  87 Service Request */
#define SRC_ID_DMACH88			300	/* DMA Channel  88 Service Request */
#define SRC_ID_DMACH89			301	/* DMA Channel  89 Service Request */
#define SRC_ID_DMACH90			302	/* DMA Channel  90 Service Request */
#define SRC_ID_DMACH91			303	/* DMA Channel  91 Service Request */
#define SRC_ID_DMACH92			304	/* DMA Channel  92 Service Request */
#define SRC_ID_DMACH93			305	/* DMA Channel  93 Service Request */
#define SRC_ID_DMACH94			306	/* DMA Channel  94 Service Request */
#define SRC_ID_DMACH95			307	/* DMA Channel  95 Service Request */
#define SRC_ID_DMACH96			308	/* DMA Channel  96 Service Request */
#define SRC_ID_DMACH97			309	/* DMA Channel  97 Service Request */
#define SRC_ID_DMACH98			310	/* DMA Channel  98 Service Request */
#define SRC_ID_DMACH99			311	/* DMA Channel  99 Service Request */
#define SRC_ID_DMACH100			312	/* DMA Channel 100 Service Request */
#define SRC_ID_DMACH101			313	/* DMA Channel 101 Service Request */
#define SRC_ID_DMACH102			314	/* DMA Channel 102 Service Request */
#define SRC_ID_DMACH103			315	/* DMA Channel 103 Service Request */
#define SRC_ID_DMACH104			316	/* DMA Channel 104 Service Request */
#define SRC_ID_DMACH105			317	/* DMA Channel 105 Service Request */
#define SRC_ID_DMACH106			318	/* DMA Channel 106 Service Request */
#define SRC_ID_DMACH107			319	/* DMA Channel 107 Service Request */
#define SRC_ID_DMACH108			320	/* DMA Channel 108 Service Request */
#define SRC_ID_DMACH109			321	/* DMA Channel 109 Service Request */
#define SRC_ID_DMACH110			322	/* DMA Channel 110 Service Request */
#define SRC_ID_DMACH111			323	/* DMA Channel 111 Service Request */
#define SRC_ID_DMACH112			324	/* DMA Channel 112 Service Request */
#define SRC_ID_DMACH113			325	/* DMA Channel 113 Service Request */
#define SRC_ID_DMACH114			326	/* DMA Channel 114 Service Request */
#define SRC_ID_DMACH115			327	/* DMA Channel 115 Service Request */
#define SRC_ID_DMACH116			328	/* DMA Channel 116 Service Request */
#define SRC_ID_DMACH117			329	/* DMA Channel 117 Service Request */
#define SRC_ID_DMACH118			330	/* DMA Channel 118 Service Request */
#define SRC_ID_DMACH119			331	/* DMA Channel 119 Service Request */
#define SRC_ID_DMACH120			332	/* DMA Channel 120 Service Request */
#define SRC_ID_DMACH121			333	/* DMA Channel 121 Service Request */
#define SRC_ID_DMACH122			334	/* DMA Channel 122 Service Request */
#define SRC_ID_DMACH123			335	/* DMA Channel 123 Service Request */
#define SRC_ID_DMACH124			336	/* DMA Channel 124 Service Request */
#define SRC_ID_DMACH125			337	/* DMA Channel 125 Service Request */
#define SRC_ID_DMACH126			338	/* DMA Channel 126 Service Request */
#define SRC_ID_DMACH127			339	/* DMA Channel 127 Service Request */

#define SRC_ID_PDMAERR			340	/* PDMA Error Service Request */
#define SRC_ID_PDMARDY			341	/* PDMA Ready Service Request */

#define SRC_ID_ETH				344	/* Ethernet Service Request */

#define SRC_ID_CAN0INT0			352	/* CAN0 Service Request 0 */
#define SRC_ID_CAN0INT1			353	/* CAN0 Service Request 1 */
#define SRC_ID_CAN0INT2			354	/* CAN0 Service Request 2 */
#define SRC_ID_CAN0INT3			355	/* CAN0 Service Request 3 */
#define SRC_ID_CAN0INT4			356	/* CAN0 Service Request 4 */
#define SRC_ID_CAN0INT5			357	/* CAN0 Service Request 5 */
#define SRC_ID_CAN0INT6			358	/* CAN0 Service Request 6 */
#define SRC_ID_CAN0INT7			359	/* CAN0 Service Request 7 */
#define SRC_ID_CAN0INT8			360	/* CAN0 Service Request 8 */
#define SRC_ID_CAN0INT9			361	/* CAN0 Service Request 9 */
#define SRC_ID_CAN0INT10		362	/* CAN0 Service Request 10 */
#define SRC_ID_CAN0INT11		363	/* CAN0 Service Request 11 */
#define SRC_ID_CAN0INT12		364	/* CAN0 Service Request 12 */
#define SRC_ID_CAN0INT13		365	/* CAN0 Service Request 13 */
#define SRC_ID_CAN0INT14		366	/* CAN0 Service Request 14 */
#define SRC_ID_CAN0INT15		367	/* CAN0 Service Request 15 */
#define SRC_ID_CAN1INT0			368	/* CAN1 Service Request 0 */
#define SRC_ID_CAN1INT1			369	/* CAN1 Service Request 1 */
#define SRC_ID_CAN1INT2			370	/* CAN1 Service Request 2 */
#define SRC_ID_CAN1INT3			371	/* CAN1 Service Request 3 */
#define SRC_ID_CAN1INT4			372	/* CAN1 Service Request 4 */
#define SRC_ID_CAN1INT5			373	/* CAN1 Service Request 5 */
#define SRC_ID_CAN1INT6			374	/* CAN1 Service Request 6 */
#define SRC_ID_CAN1INT7			375	/* CAN1 Service Request 7 */
#define SRC_ID_CAN1INT8			376	/* CAN1 Service Request 8 */
#define SRC_ID_CAN1INT9			377	/* CAN1 Service Request 9 */
#define SRC_ID_CAN1INT10		378	/* CAN1 Service Request 10 */
#define SRC_ID_CAN1INT11		379	/* CAN1 Service Request 11 */
#define SRC_ID_CAN1INT12		380	/* CAN1 Service Request 12 */
#define SRC_ID_CAN1INT13		381	/* CAN1 Service Request 13 */
#define SRC_ID_CAN1INT14		382	/* CAN1 Service Request 14 */
#define SRC_ID_CAN1INT15		383	/* CAN1 Service Request 15 */
#define SRC_ID_CAN2INT0			384	/* CAN2 Service Request 0 */
#define SRC_ID_CAN2INT1			385	/* CAN2 Service Request 1 */
#define SRC_ID_CAN2INT2			386	/* CAN2 Service Request 2 */
#define SRC_ID_CAN2INT3			387	/* CAN2 Service Request 3 */
#define SRC_ID_CAN2INT4			388	/* CAN2 Service Request 4 */
#define SRC_ID_CAN2INT5			389	/* CAN2 Service Request 5 */
#define SRC_ID_CAN2INT6			390	/* CAN2 Service Request 6 */
#define SRC_ID_CAN2INT7			391	/* CAN2 Service Request 7 */
#define SRC_ID_CAN2INT8			392	/* CAN2 Service Request 8 */
#define SRC_ID_CAN2INT9			393	/* CAN2 Service Request 9 */
#define SRC_ID_CAN2INT10		394	/* CAN2 Service Request 10 */
#define SRC_ID_CAN2INT11		395	/* CAN2 Service Request 11 */
#define SRC_ID_CAN2INT12		396	/* CAN2 Service Request 12 */
#define SRC_ID_CAN2INT13		397	/* CAN2 Service Request 13 */
#define SRC_ID_CAN2INT14		398	/* CAN2 Service Request 14 */
#define SRC_ID_CAN2INT15		399	/* CAN2 Service Request 15 */

#define SRC_ID_VADCG0SR0		412	/* VADC Group  0 Service Request 0 */
#define SRC_ID_VADCG0SR1		413	/* VADC Group  0 Service Request 1 */
#define SRC_ID_VADCG0SR2		414	/* VADC Group  0 Service Request 2 */
#define SRC_ID_VADCG0SR3		415	/* VADC Group  0 Service Request 3 */
#define SRC_ID_VADCG1SR0		416	/* VADC Group  1 Service Request 0 */
#define SRC_ID_VADCG1SR1		417	/* VADC Group  1 Service Request 1 */
#define SRC_ID_VADCG1SR2		418	/* VADC Group  1 Service Request 2 */
#define SRC_ID_VADCG1SR3		419	/* VADC Group  1 Service Request 3 */
#define SRC_ID_VADCG2SR0		420	/* VADC Group  2 Service Request 0 */
#define SRC_ID_VADCG2SR1		421	/* VADC Group  2 Service Request 1 */
#define SRC_ID_VADCG2SR2		422	/* VADC Group  2 Service Request 2 */
#define SRC_ID_VADCG2SR3		423	/* VADC Group  2 Service Request 3 */
#define SRC_ID_VADCG3SR0		424	/* VADC Group  3 Service Request 0 */
#define SRC_ID_VADCG3SR1		425	/* VADC Group  3 Service Request 1 */
#define SRC_ID_VADCG3SR2		426	/* VADC Group  3 Service Request 2 */
#define SRC_ID_VADCG3SR3		427	/* VADC Group  3 Service Request 3 */
#define SRC_ID_VADCG4SR0		428	/* VADC Group  4 Service Request 0 */
#define SRC_ID_VADCG4SR1		429	/* VADC Group  4 Service Request 1 */
#define SRC_ID_VADCG4SR2		430	/* VADC Group  4 Service Request 2 */
#define SRC_ID_VADCG4SR3		431	/* VADC Group  4 Service Request 3 */
#define SRC_ID_VADCG5SR0		432	/* VADC Group  5 Service Request 0 */
#define SRC_ID_VADCG5SR1		433	/* VADC Group  5 Service Request 1 */
#define SRC_ID_VADCG5SR2		434	/* VADC Group  5 Service Request 2 */
#define SRC_ID_VADCG5SR3		435	/* VADC Group  5 Service Request 3 */
#define SRC_ID_VADCG6SR0		436	/* VADC Group  6 Service Request 0 */
#define SRC_ID_VADCG6SR1		437	/* VADC Group  6 Service Request 1 */
#define SRC_ID_VADCG6SR2		438	/* VADC Group  6 Service Request 2 */
#define SRC_ID_VADCG6SR3		439	/* VADC Group  6 Service Request 3 */
#define SRC_ID_VADCG7SR0		440	/* VADC Group  7 Service Request 0 */
#define SRC_ID_VADCG7SR1		441	/* VADC Group  7 Service Request 1 */
#define SRC_ID_VADCG7SR2		442	/* VADC Group  7 Service Request 2 */
#define SRC_ID_VADCG7SR3		443	/* VADC Group  7 Service Request 3 */
#define SRC_ID_VADCG8SR0		444	/* VADC Group  8 Service Request 0 */
#define SRC_ID_VADCG8SR1		445	/* VADC Group  8 Service Request 1 */
#define SRC_ID_VADCG8SR2		446	/* VADC Group  8 Service Request 2 */
#define SRC_ID_VADCG8SR3		447	/* VADC Group  8 Service Request 3 */
#define SRC_ID_VADCG9SR0		448	/* VADC Group  9 Service Request 0 */
#define SRC_ID_VADCG9SR1		449	/* VADC Group  9 Service Request 1 */
#define SRC_ID_VADCG9SR2		450	/* VADC Group  9 Service Request 2 */
#define SRC_ID_VADCG9SR3		451	/* VADC Group  9 Service Request 3 */
#define SRC_ID_VADCG10SR0		452	/* VADC Group 10 Service Request 0 */
#define SRC_ID_VADCG10SR1		453	/* VADC Group 10 Service Request 1 */
#define SRC_ID_VADCG10SR2		454	/* VADC Group 10 Service Request 2 */
#define SRC_ID_VADCG10SR3		455	/* VADC Group 10 Service Request 3 */
#define SRC_ID_VADCG11SR0		456	/* VADC Group 11 Service Request 0 */
#define SRC_ID_VADCG11SR1		457	/* VADC Group 11 Service Request 1 */
#define SRC_ID_VADCG11SR2		458	/* VADC Group 11 Service Request 2 */
#define SRC_ID_VADCG11SR3		459	/* VADC Group 11 Service Request 3 */
#define SRC_ID_VADCG12SR0		460	/* VADC Group 12 Service Request 0 */
#define SRC_ID_VADCG13SR0		461	/* VADC Group 13 Service Request 0 */
#define SRC_ID_VADCG14SR0		462	/* VADC Group 14 Service Request 0 */
#define SRC_ID_VADCG15SR0		463	/* VADC Group 15 Service Request 0 */
#define SRC_ID_VADCG16SR0		464	/* VADC Group 16 Service Request 0 */
#define SRC_ID_VADCG17SR0		465	/* VADC Group 17 Service Request 0 */
#define SRC_ID_VADCG18SR0		466	/* VADC Group 18 Service Request 0 */
#define SRC_ID_VADCG19SR0		467	/* VADC Group 19 Service Request 0 */
#define SRC_ID_VADCCG0SR0		468	/* VADC Common Group 0 Service Request 0 */
#define SRC_ID_VADCCG0SR1		469	/* VADC Common Group 0 Service Request 1 */
#define SRC_ID_VADCCG0SR2		470	/* VADC Common Group 0 Service Request 2 */
#define SRC_ID_VADCCG0SR3		471	/* VADC Common Group 0 Service Request 3 */
#define SRC_ID_VADCCG1SR0		472	/* VADC Common Group 1 Service Request 0 */
#define SRC_ID_VADCCG1SR1		473	/* VADC Common Group 1 Service Request 1 */
#define SRC_ID_VADCCG1SR2		474	/* VADC Common Group 1 Service Request 2 */
#define SRC_ID_VADCCG1SR3		475	/* VADC Common Group 1 Service Request 3 */

#define SRC_ID_DSADCSRM0		476	/* DSADC SRM0 Service Request */
#define SRC_ID_DSADCSRA0		477	/* DSADC SRA0 Service Request */
#define SRC_ID_DSADCSRM1		478	/* DSADC SRM1 Service Request */
#define SRC_ID_DSADCSRA1		479	/* DSADC SRA1 Service Request */
#define SRC_ID_DSADCSRM2		480	/* DSADC SRM2 Service Request */
#define SRC_ID_DSADCSRA2		481	/* DSADC SRA2 Service Request */
#define SRC_ID_DSADCSRM3		482	/* DSADC SRM3 Service Request */
#define SRC_ID_DSADCSRA3		483	/* DSADC SRA3 Service Request */
#define SRC_ID_DSADCSRM4		484	/* DSADC SRM4 Service Request */
#define SRC_ID_DSADCSRA4		485	/* DSADC SRA4 Service Request */
#define SRC_ID_DSADCSRM5		486	/* DSADC SRM5 Service Request */
#define SRC_ID_DSADCSRA5		487	/* DSADC SRA5 Service Request */
#define SRC_ID_DSADCSRM6		488	/* DSADC SRM6 Service Request */
#define SRC_ID_DSADCSRA6		489	/* DSADC SRA6 Service Request */
#define SRC_ID_DSADCSRM7		490	/* DSADC SRM7 Service Request */
#define SRC_ID_DSADCSRA7		491	/* DSADC SRA7 Service Request */
#define SRC_ID_DSADCSRM8		492	/* DSADC SRM8 Service Request */
#define SRC_ID_DSADCSRA8		493	/* DSADC SRA8 Service Request */
#define SRC_ID_DSADCSRM9		494	/* DSADC SRM9 Service Request */
#define SRC_ID_DSADCSRA9		495	/* DSADC SRA9 Service Request */
#define SRC_ID_DSADCSRM10		496	/* DSADC SRM10 Service Request */
#define SRC_ID_DSADCSRA10		497	/* DSADC SRA10 Service Request */
#define SRC_ID_DSADCSRM11		498	/* DSADC SRM11 Service Request */
#define SRC_ID_DSADCSRA11		499	/* DSADC SRA11 Service Request */
#define SRC_ID_DSADCSRM12		500	/* DSADC SRM12 Service Request */
#define SRC_ID_DSADCSRA12		501	/* DSADC SRA12 Service Request */
#define SRC_ID_DSADCSRM13		502	/* DSADC SRM13 Service Request */
#define SRC_ID_DSADCSRA13		503	/* DSADC SRA13 Service Request */

#define SRC_ID_ERAY0INT0		512	/* E-RAY 0 Service Request 0 */
#define SRC_ID_ERAY0INT1		513	/* E-RAY 0 Service Request 1 */
#define SRC_ID_ERAY0TINT0		514	/* E-RAY 0 Timer Interrupt 0 Service Request */
#define SRC_ID_ERAY0TINT1		515	/* E-RAY 0 Timer Interrupt 1 Service Request */
#define SRC_ID_ERAY0NDAT0		516	/* E-RAY 0 New Data 0 Service Request */
#define SRC_ID_ERAY0NDAT1		517	/* E-RAY 0 New Data 1 Service Request */
#define SRC_ID_ERAY0MBSC0		518	/* E-RAY 0 Message Buffer Status Changed 0 Service Request */
#define SRC_ID_ERAY0MBSC1		519	/* E-RAY 0 Message Buffer Status Changed 1 Service Request */
#define SRC_ID_ERAY0OBUSY		520	/* E-RAY 0 Output Buffer Busy Service Request */
#define SRC_ID_ERAY0IBUSY		521	/* E-RAY 0 Input Buffer Busy Service Request */
#define SRC_ID_ERAY1INT0		524	/* E-RAY 1 Service Request 0 */
#define SRC_ID_ERAY1INT1		525	/* E-RAY 1 Service Request 1 */
#define SRC_ID_ERAY1TINT0		526	/* E-RAY 1 Timer Interrupt 0 Service Request */
#define SRC_ID_ERAY1TINT1		527	/* E-RAY 1 Timer Interrupt 1 Service Request */
#define SRC_ID_ERAY1NDAT0		528	/* E-RAY 1 New Data 0 Service Request */
#define SRC_ID_ERAY1NDAT1		529	/* E-RAY 1 New Data 1 Service Request */
#define SRC_ID_ERAY1MBSC0		530	/* E-RAY 1 Message Buffer Status Changed 0 Service Request */
#define SRC_ID_ERAY1MBSC1		531	/* E-RAY 1 Message Buffer Status Changed 1 Service Request */
#define SRC_ID_ERAY1OBUSY		532	/* E-RAY 1 Output Buffer Busy Service Request */
#define SRC_ID_ERAY1IBUSY		533	/* E-RAY 1 Input Buffer Busy Service Request */

#define SRC_ID_PMUHOST			536	/* PMU Host Service Request */
#define SRC_ID_PMUFSI			537	/* PMU FSI Service Request */

#define SRC_ID_HSM0				540	/* HSM Service Request 0 */
#define SRC_ID_HSM1				541	/* HSM Service Request 1 */

#define SRC_ID_SCUERU0			544	/* SCU ERU Service Request 0 */
#define SRC_ID_SCUERU1			545	/* SCU ERU Service Request 1 */
#define SRC_ID_SCUERU2			546	/* SCU ERU Service Request 2 */
#define SRC_ID_SCUERU3			547	/* SCU ERU Service Request 3 */

#define SRC_ID_PMSDTS			551	/* PMS DTS Service Request */
#define SRC_ID_PMS0				552	/* PMS Service Request 0 */
#define SRC_ID_PMS1				553	/* PMS Service Request 1 */
#define SRC_ID_PMS2				554	/* PMS Service Request 2 */
#define SRC_ID_PMS3				555	/* PMS Service Request 3 */
#define SRC_ID_SCR				556	/* Standby Controller (SCR) Service Request */

#define SRC_ID_SMU0				560	/* SMU Service Request 0 */
#define SRC_ID_SMU1				561	/* SMU Service Request 1 */
#define SRC_ID_SMU2				562	/* SMU Service Request 2 */

#define SRC_ID_PSI50			564	/* PSI5 Service Request 0 */
#define SRC_ID_PSI51			565	/* PSI5 Service Request 1 */
#define SRC_ID_PSI52			566	/* PSI5 Service Request 2 */
#define SRC_ID_PSI53			567	/* PSI5 Service Request 3 */
#define SRC_ID_PSI54			568	/* PSI5 Service Request 4 */
#define SRC_ID_PSI55			569	/* PSI5 Service Request 5 */
#define SRC_ID_PSI56			570	/* PSI5 Service Request 6 */
#define SRC_ID_PSI57			571	/* PSI5 Service Request 7 */

#define SRC_ID_DAM0LI0			576	/* DAM0 Limit 0 Service Request */
#define SRC_ID_DAM0RI0			577	/* DAM0 Ready 0 Service Request */
#define SRC_ID_DAM0LI1			578	/* DAM0 Limit 1 Service Request */
#define SRC_ID_DAM0RI1			579	/* DAM0 Ready 1 Service Request */
#define SRC_ID_DAM0DR			580	/* DAM0 DMA Ready Service Request */
#define SRC_ID_DAM0ERR			581	/* DAM0 Error Service Request */
#define SRC_ID_DAM1LI0			582	/* DAM1 Limit 0 Service Request */
#define SRC_ID_DAM1RI0			583	/* DAM1 Ready 0 Service Request */
#define SRC_ID_DAM1LI1			584	/* DAM1 Limit 1 Service Request */
#define SRC_ID_DAM1RI1			585	/* DAM1 Ready 1 Service Request */
#define SRC_ID_DAM1DR			586	/* DAM1 DMA Ready Service Request */
#define SRC_ID_DAM1ERR			587	/* DAM1 Error Service Request */

#define SRC_ID_CIFMI			588	/* CIF MI Service Request */
#define SRC_ID_CIFMIEP			589	/* CIF MI EP Service Request */
#define SRC_ID_CIFISP			590	/* CIF ISP Service Request */
#define SRC_ID_CIFMJPEG			591	/* CIF MJPEG Service Request */

#define SRC_ID_PSI5S0			596	/* PSI5-S Service Request 0 */
#define SRC_ID_PSI5S1			597	/* PSI5-S Service Request 1 */
#define SRC_ID_PSI5S2			598	/* PSI5-S Service Request 2 */
#define SRC_ID_PSI5S3			599	/* PSI5-S Service Request 3 */
#define SRC_ID_PSI5S4			600	/* PSI5-S Service Request 4 */
#define SRC_ID_PSI5S5			601	/* PSI5-S Service Request 5 */
#define SRC_ID_PSI5S6			602	/* PSI5-S Service Request 6 */
#define SRC_ID_PSI5S7			603	/* PSI5-S Service Request 7 */

#define SRC_ID_RIF0ERR			604	/* RIF 0 Error Service Request */
#define SRC_ID_RIF0INT			605	/* RIF 0 Service Request */
#define SRC_ID_RIF1ERR			606	/* RIF 1 Error Service Request */
#define SRC_ID_RIF1INT			607	/* RIF 1 Service Request */

#define SRC_ID_SPU0ERR			608	/* SPU 0 Error Service Request */
#define SRC_ID_SPU0INT			609	/* SPU 0 Service Request */
#define SRC_ID_SPU1ERR			610	/* SPU 1 Error Service Request */
#define SRC_ID_SPU1INT			611	/* SPU 1 Service Request */

#define SRC_ID_GPSR00			612	/* General Purpose Service Request 0 0 */
#define SRC_ID_GPSR01			613	/* General Purpose Service Request 0 1 */
#define SRC_ID_GPSR02			614	/* General Purpose Service Request 0 2 */
#define SRC_ID_GPSR03			615	/* General Purpose Service Request 0 3 */
#define SRC_ID_GPSR04			616	/* General Purpose Service Request 0 4 */
#define SRC_ID_GPSR05			617	/* General Purpose Service Request 0 5 */
#define SRC_ID_GPSR06			618	/* General Purpose Service Request 0 6 */
#define SRC_ID_GPSR07			619	/* General Purpose Service Request 0 7 */

#define SRC_ID_GPSR10			620	/* General Purpose Service Request 1 0 */
#define SRC_ID_GPSR11			621	/* General Purpose Service Request 1 1 */
#define SRC_ID_GPSR12			622	/* General Purpose Service Request 1 2 */
#define SRC_ID_GPSR13			623	/* General Purpose Service Request 1 3 */
#define SRC_ID_GPSR14			624	/* General Purpose Service Request 1 4 */
#define SRC_ID_GPSR15			625	/* General Purpose Service Request 1 5 */
#define SRC_ID_GPSR16			626	/* General Purpose Service Request 1 6 */
#define SRC_ID_GPSR17			627	/* General Purpose Service Request 1 7 */

#define SRC_ID_GPSR20			628	/* General Purpose Service Request 2 0 */
#define SRC_ID_GPSR21			629	/* General Purpose Service Request 2 1 */
#define SRC_ID_GPSR22			630	/* General Purpose Service Request 2 2 */
#define SRC_ID_GPSR23			631	/* General Purpose Service Request 2 3 */
#define SRC_ID_GPSR24			632	/* General Purpose Service Request 2 4 */
#define SRC_ID_GPSR25			633	/* General Purpose Service Request 2 5 */
#define SRC_ID_GPSR26			634	/* General Purpose Service Request 2 6 */
#define SRC_ID_GPSR27			635	/* General Purpose Service Request 2 7 */

#define SRC_ID_GPSR30			636	/* General Purpose Service Request 3 0 */
#define SRC_ID_GPSR31			637	/* General Purpose Service Request 3 1 */
#define SRC_ID_GPSR32			638	/* General Purpose Service Request 3 2 */
#define SRC_ID_GPSR33			639	/* General Purpose Service Request 3 3 */
#define SRC_ID_GPSR34			640	/* General Purpose Service Request 3 4 */
#define SRC_ID_GPSR35			641	/* General Purpose Service Request 3 5 */
#define SRC_ID_GPSR36			642	/* General Purpose Service Request 3 6 */
#define SRC_ID_GPSR37			643	/* General Purpose Service Request 3 7 */

#define SRC_ID_GPSR40			644	/* General Purpose Service Request 4 0 */
#define SRC_ID_GPSR41			645	/* General Purpose Service Request 4 1 */
#define SRC_ID_GPSR42			646	/* General Purpose Service Request 4 2 */
#define SRC_ID_GPSR43			647	/* General Purpose Service Request 4 3 */
#define SRC_ID_GPSR44			648	/* General Purpose Service Request 4 4 */
#define SRC_ID_GPSR45			649	/* General Purpose Service Request 4 5 */
#define SRC_ID_GPSR46			650	/* General Purpose Service Request 4 6 */
#define SRC_ID_GPSR47			651	/* General Purpose Service Request 4 7 */

#define SRC_ID_GPSR50			652	/* General Purpose Service Request 5 0 */
#define SRC_ID_GPSR51			653	/* General Purpose Service Request 5 1 */
#define SRC_ID_GPSR52			654	/* General Purpose Service Request 5 2 */
#define SRC_ID_GPSR53			655	/* General Purpose Service Request 5 3 */
#define SRC_ID_GPSR54			656	/* General Purpose Service Request 5 4 */
#define SRC_ID_GPSR55			657	/* General Purpose Service Request 5 5 */
#define SRC_ID_GPSR56			658	/* General Purpose Service Request 5 6 */
#define SRC_ID_GPSR57			659	/* General Purpose Service Request 5 7 */

#define SRC_ID_GTMAEIIRQ		668	/* GTM AEI Shared Service Request */
#define SRC_ID_GTMARUIRQ0		669	/* GTM ARU Shared Service Request 0 */
#define SRC_ID_GTMARUIRQ1		670	/* GTM ARU Shared Service Request 1 */
#define SRC_ID_GTMARUIRQ2		671	/* GTM ARU Shared Service Request 2 */

#define SRC_ID_GTMBRCIRQ		672	/* GTM BRC Shared Service Request */
#define SRC_ID_GTMCMPIRQ		673	/* GTM CMP Shared Service Request */
#define SRC_ID_GTMSPE0IRQ		674	/* GTM SPE0 Shared Service Request */
#define SRC_ID_GTMSPE1IRQ		675	/* GTM SPE1 Shared Service Request */
#define SRC_ID_GTMSPE2IRQ		676	/* GTM SPE2 Shared Service Request */
#define SRC_ID_GTMSPE3IRQ		677	/* GTM SPE3 Shared Service Request */
#define SRC_ID_GTMSPE4IRQ		678	/* GTM SPE4 Shared Service Request */
#define SRC_ID_GTMSPE5IRQ		679	/* GTM SPE5 Shared Service Request */

#define SRC_ID_GTMPSM00			680	/* GTM PSM0 Shared Service Request 0 */
#define SRC_ID_GTMPSM01			681	/* GTM PSM0 Shared Service Request 1 */
#define SRC_ID_GTMPSM02			682	/* GTM PSM0 Shared Service Request 2 */
#define SRC_ID_GTMPSM03			683	/* GTM PSM0 Shared Service Request 3 */
#define SRC_ID_GTMPSM04			684	/* GTM PSM0 Shared Service Request 4 */
#define SRC_ID_GTMPSM05			685	/* GTM PSM0 Shared Service Request 5 */
#define SRC_ID_GTMPSM06			686	/* GTM PSM0 Shared Service Request 6 */
#define SRC_ID_GTMPSM07			687	/* GTM PSM0 Shared Service Request 7 */

#define SRC_ID_GTMPSM10			688	/* GTM PSM1 Shared Service Request 0 */
#define SRC_ID_GTMPSM11			689	/* GTM PSM1 Shared Service Request 1 */
#define SRC_ID_GTMPSM12			690	/* GTM PSM1 Shared Service Request 2 */
#define SRC_ID_GTMPSM13			691	/* GTM PSM1 Shared Service Request 3 */
#define SRC_ID_GTMPSM14			692	/* GTM PSM1 Shared Service Request 4 */
#define SRC_ID_GTMPSM15			693	/* GTM PSM1 Shared Service Request 5 */
#define SRC_ID_GTMPSM16			694	/* GTM PSM1 Shared Service Request 6 */
#define SRC_ID_GTMPSM17			695	/* GTM PSM1 Shared Service Request 7 */

#define SRC_ID_GTMPSM20			696	/* GTM PSM2 Shared Service Request 0 */
#define SRC_ID_GTMPSM21			697	/* GTM PSM2 Shared Service Request 1 */
#define SRC_ID_GTMPSM22			698	/* GTM PSM2 Shared Service Request 2 */
#define SRC_ID_GTMPSM23			699	/* GTM PSM2 Shared Service Request 3 */
#define SRC_ID_GTMPSM24			700	/* GTM PSM2 Shared Service Request 4 */
#define SRC_ID_GTMPSM25			701	/* GTM PSM2 Shared Service Request 5 */
#define SRC_ID_GTMPSM26			702	/* GTM PSM2 Shared Service Request 6 */
#define SRC_ID_GTMPSM27			703	/* GTM PSM2 Shared Service Request 7 */

#define SRC_ID_GTMDPLL0			704	/* GTM DPLL Service Request 0 */
#define SRC_ID_GTMDPLL1			705	/* GTM DPLL Service Request 1 */
#define SRC_ID_GTMDPLL2			706	/* GTM DPLL Service Request 2 */
#define SRC_ID_GTMDPLL3			707	/* GTM DPLL Service Request 3 */
#define SRC_ID_GTMDPLL4			708	/* GTM DPLL Service Request 4 */
#define SRC_ID_GTMDPLL5			709	/* GTM DPLL Service Request 5 */
#define SRC_ID_GTMDPLL6			710	/* GTM DPLL Service Request 6 */
#define SRC_ID_GTMDPLL7			711	/* GTM DPLL Service Request 7 */
#define SRC_ID_GTMDPLL8			712	/* GTM DPLL Service Request 8 */
#define SRC_ID_GTMDPLL9			713	/* GTM DPLL Service Request 9 */
#define SRC_ID_GTMDPLL10		714	/* GTM DPLL Service Request 10 */
#define SRC_ID_GTMDPLL11		715	/* GTM DPLL Service Request 11 */
#define SRC_ID_GTMDPLL12		716	/* GTM DPLL Service Request 12 */
#define SRC_ID_GTMDPLL13		717	/* GTM DPLL Service Request 13 */
#define SRC_ID_GTMDPLL14		718	/* GTM DPLL Service Request 14 */
#define SRC_ID_GTMDPLL15		719	/* GTM DPLL Service Request 15 */
#define SRC_ID_GTMDPLL16		720	/* GTM DPLL Service Request 16 */
#define SRC_ID_GTMDPLL17		721	/* GTM DPLL Service Request 17 */
#define SRC_ID_GTMDPLL18		722	/* GTM DPLL Service Request 18 */
#define SRC_ID_GTMDPLL19		723	/* GTM DPLL Service Request 19 */
#define SRC_ID_GTMDPLL20		724	/* GTM DPLL Service Request 20 */
#define SRC_ID_GTMDPLL21		725	/* GTM DPLL Service Request 21 */
#define SRC_ID_GTMDPLL22		726	/* GTM DPLL Service Request 22 */
#define SRC_ID_GTMDPLL23		727	/* GTM DPLL Service Request 23 */
#define SRC_ID_GTMDPLL24		728	/* GTM DPLL Service Request 24 */
#define SRC_ID_GTMDPLL25		729	/* GTM DPLL Service Request 25 */
#define SRC_ID_GTMDPLL26		730	/* GTM DPLL Service Request 26 */

#define SRC_ID_GTMERR			732	/* GTM Error Service Request */

#define SRC_ID_GTMTIM00			740	/* GTM TIM0 Shared Service Request 0 */
#define SRC_ID_GTMTIM01			741	/* GTM TIM0 Shared Service Request 1 */
#define SRC_ID_GTMTIM02			742	/* GTM TIM0 Shared Service Request 2 */
#define SRC_ID_GTMTIM03			743	/* GTM TIM0 Shared Service Request 3 */
#define SRC_ID_GTMTIM04			744	/* GTM TIM0 Shared Service Request 4 */
#define SRC_ID_GTMTIM05			745	/* GTM TIM0 Shared Service Request 5 */
#define SRC_ID_GTMTIM06			746	/* GTM TIM0 Shared Service Request 6 */
#define SRC_ID_GTMTIM07			747	/* GTM TIM0 Shared Service Request 7 */
#define SRC_ID_GTMTIM10			748	/* GTM TIM1 Shared Service Request 0 */
#define SRC_ID_GTMTIM11			749	/* GTM TIM1 Shared Service Request 1 */
#define SRC_ID_GTMTIM12			750	/* GTM TIM1 Shared Service Request 2 */
#define SRC_ID_GTMTIM13			751	/* GTM TIM1 Shared Service Request 3 */
#define SRC_ID_GTMTIM14			752	/* GTM TIM1 Shared Service Request 4 */
#define SRC_ID_GTMTIM15			753	/* GTM TIM1 Shared Service Request 5 */
#define SRC_ID_GTMTIM16			754	/* GTM TIM1 Shared Service Request 6 */
#define SRC_ID_GTMTIM17			755	/* GTM TIM1 Shared Service Request 7 */
#define SRC_ID_GTMTIM20			756	/* GTM TIM2 Shared Service Request 0 */
#define SRC_ID_GTMTIM21			757	/* GTM TIM2 Shared Service Request 1 */
#define SRC_ID_GTMTIM22			758	/* GTM TIM2 Shared Service Request 2 */
#define SRC_ID_GTMTIM23			759	/* GTM TIM2 Shared Service Request 3 */
#define SRC_ID_GTMTIM24			760	/* GTM TIM2 Shared Service Request 4 */
#define SRC_ID_GTMTIM25			761	/* GTM TIM2 Shared Service Request 5 */
#define SRC_ID_GTMTIM26			762	/* GTM TIM2 Shared Service Request 6 */
#define SRC_ID_GTMTIM27			763	/* GTM TIM2 Shared Service Request 7 */
#define SRC_ID_GTMTIM30			764	/* GTM TIM3 Shared Service Request 0 */
#define SRC_ID_GTMTIM31			765	/* GTM TIM3 Shared Service Request 1 */
#define SRC_ID_GTMTIM32			766	/* GTM TIM3 Shared Service Request 2 */
#define SRC_ID_GTMTIM33			767	/* GTM TIM3 Shared Service Request 3 */
#define SRC_ID_GTMTIM34			768	/* GTM TIM3 Shared Service Request 4 */
#define SRC_ID_GTMTIM35			769	/* GTM TIM3 Shared Service Request 5 */
#define SRC_ID_GTMTIM36			770	/* GTM TIM3 Shared Service Request 6 */
#define SRC_ID_GTMTIM37			771	/* GTM TIM3 Shared Service Request 7 */
#define SRC_ID_GTMTIM40			772	/* GTM TIM4 Shared Service Request 0 */
#define SRC_ID_GTMTIM41			773	/* GTM TIM4 Shared Service Request 1 */
#define SRC_ID_GTMTIM42			774	/* GTM TIM4 Shared Service Request 2 */
#define SRC_ID_GTMTIM43			775	/* GTM TIM4 Shared Service Request 3 */
#define SRC_ID_GTMTIM44			776	/* GTM TIM4 Shared Service Request 4 */
#define SRC_ID_GTMTIM45			777	/* GTM TIM4 Shared Service Request 5 */
#define SRC_ID_GTMTIM46			778	/* GTM TIM4 Shared Service Request 6 */
#define SRC_ID_GTMTIM47			779	/* GTM TIM4 Shared Service Request 7 */
#define SRC_ID_GTMTIM50			780	/* GTM TIM5 Shared Service Request 0 */
#define SRC_ID_GTMTIM51			781	/* GTM TIM5 Shared Service Request 1 */
#define SRC_ID_GTMTIM52			782	/* GTM TIM5 Shared Service Request 2 */
#define SRC_ID_GTMTIM53			783	/* GTM TIM5 Shared Service Request 3 */
#define SRC_ID_GTMTIM54			784	/* GTM TIM5 Shared Service Request 4 */
#define SRC_ID_GTMTIM55			785	/* GTM TIM5 Shared Service Request 5 */
#define SRC_ID_GTMTIM56			786	/* GTM TIM5 Shared Service Request 6 */
#define SRC_ID_GTMTIM57			787	/* GTM TIM5 Shared Service Request 7 */
#define SRC_ID_GTMTIM60			788	/* GTM TIM6 Shared Service Request 0 */
#define SRC_ID_GTMTIM61			789	/* GTM TIM6 Shared Service Request 1 */
#define SRC_ID_GTMTIM62			790	/* GTM TIM6 Shared Service Request 2 */
#define SRC_ID_GTMTIM63			791	/* GTM TIM6 Shared Service Request 3 */
#define SRC_ID_GTMTIM64			792	/* GTM TIM6 Shared Service Request 4 */
#define SRC_ID_GTMTIM65			793	/* GTM TIM6 Shared Service Request 5 */
#define SRC_ID_GTMTIM66			794	/* GTM TIM6 Shared Service Request 6 */
#define SRC_ID_GTMTIM67			795	/* GTM TIM6 Shared Service Request 7 */
#define SRC_ID_GTMTIM70			796	/* GTM TIM7 Shared Service Request 0 */
#define SRC_ID_GTMTIM71			797	/* GTM TIM7 Shared Service Request 1 */
#define SRC_ID_GTMTIM72			798	/* GTM TIM7 Shared Service Request 2 */
#define SRC_ID_GTMTIM73			799	/* GTM TIM7 Shared Service Request 3 */
#define SRC_ID_GTMTIM74			800	/* GTM TIM7 Shared Service Request 4 */
#define SRC_ID_GTMTIM75			801	/* GTM TIM7 Shared Service Request 5 */
#define SRC_ID_GTMTIM76			802	/* GTM TIM7 Shared Service Request 6 */
#define SRC_ID_GTMTIM77			803	/* GTM TIM7 Shared Service Request 7 */

#define SRC_ID_GTMMSC00			812	/* GTM MCS0 Shared Service Request 0 */
#define SRC_ID_GTMMSC01			813	/* GTM MCS0 Shared Service Request 1 */
#define SRC_ID_GTMMSC02			814	/* GTM MCS0 Shared Service Request 2 */
#define SRC_ID_GTMMSC03			815	/* GTM MCS0 Shared Service Request 3 */
#define SRC_ID_GTMMSC04			816	/* GTM MCS0 Shared Service Request 4 */
#define SRC_ID_GTMMSC05			817	/* GTM MCS0 Shared Service Request 5 */
#define SRC_ID_GTMMSC06			818	/* GTM MCS0 Shared Service Request 6 */
#define SRC_ID_GTMMSC07			819	/* GTM MCS0 Shared Service Request 7 */
#define SRC_ID_GTMMSC10			820	/* GTM MCS1 Shared Service Request 0 */
#define SRC_ID_GTMMSC11			821	/* GTM MCS1 Shared Service Request 1 */
#define SRC_ID_GTMMSC12			822	/* GTM MCS1 Shared Service Request 2 */
#define SRC_ID_GTMMSC13			823	/* GTM MCS1 Shared Service Request 3 */
#define SRC_ID_GTMMSC14			824	/* GTM MCS1 Shared Service Request 4 */
#define SRC_ID_GTMMSC15			825	/* GTM MCS1 Shared Service Request 5 */
#define SRC_ID_GTMMSC16			826	/* GTM MCS1 Shared Service Request 6 */
#define SRC_ID_GTMMSC17			827	/* GTM MCS1 Shared Service Request 7 */
#define SRC_ID_GTMMSC20			828	/* GTM MCS2 Shared Service Request 0 */
#define SRC_ID_GTMMSC21			829	/* GTM MCS2 Shared Service Request 1 */
#define SRC_ID_GTMMSC22			830	/* GTM MCS2 Shared Service Request 2 */
#define SRC_ID_GTMMSC23			831	/* GTM MCS2 Shared Service Request 3 */
#define SRC_ID_GTMMSC24			832	/* GTM MCS2 Shared Service Request 4 */
#define SRC_ID_GTMMSC25			833	/* GTM MCS2 Shared Service Request 5 */
#define SRC_ID_GTMMSC26			834	/* GTM MCS2 Shared Service Request 6 */
#define SRC_ID_GTMMSC27			835	/* GTM MCS2 Shared Service Request 7 */
#define SRC_ID_GTMMSC30			836	/* GTM MCS3 Shared Service Request 0 */
#define SRC_ID_GTMMSC31			837	/* GTM MCS3 Shared Service Request 1 */
#define SRC_ID_GTMMSC32			838	/* GTM MCS3 Shared Service Request 2 */
#define SRC_ID_GTMMSC33			839	/* GTM MCS3 Shared Service Request 3 */
#define SRC_ID_GTMMSC34			840	/* GTM MCS3 Shared Service Request 4 */
#define SRC_ID_GTMMSC35			841	/* GTM MCS3 Shared Service Request 5 */
#define SRC_ID_GTMMSC36			842	/* GTM MCS3 Shared Service Request 6 */
#define SRC_ID_GTMMSC37			843	/* GTM MCS3 Shared Service Request 7 */
#define SRC_ID_GTMMSC40			844	/* GTM MCS4 Shared Service Request 0 */
#define SRC_ID_GTMMSC41			845	/* GTM MCS4 Shared Service Request 1 */
#define SRC_ID_GTMMSC42			846	/* GTM MCS4 Shared Service Request 2 */
#define SRC_ID_GTMMSC43			847	/* GTM MCS4 Shared Service Request 3 */
#define SRC_ID_GTMMSC44			848	/* GTM MCS4 Shared Service Request 4 */
#define SRC_ID_GTMMSC45			849	/* GTM MCS4 Shared Service Request 5 */
#define SRC_ID_GTMMSC46			850	/* GTM MCS4 Shared Service Request 6 */
#define SRC_ID_GTMMSC47			851	/* GTM MCS4 Shared Service Request 7 */
#define SRC_ID_GTMMSC50			852	/* GTM MCS5 Shared Service Request 0 */
#define SRC_ID_GTMMSC51			853	/* GTM MCS5 Shared Service Request 1 */
#define SRC_ID_GTMMSC52			854	/* GTM MCS5 Shared Service Request 2 */
#define SRC_ID_GTMMSC53			855	/* GTM MCS5 Shared Service Request 3 */
#define SRC_ID_GTMMSC54			856	/* GTM MCS5 Shared Service Request 4 */
#define SRC_ID_GTMMSC55			857	/* GTM MCS5 Shared Service Request 5 */
#define SRC_ID_GTMMSC56			858	/* GTM MCS5 Shared Service Request 6 */
#define SRC_ID_GTMMSC57			859	/* GTM MCS5 Shared Service Request 7 */
#define SRC_ID_GTMMSC60			860	/* GTM MCS6 Shared Service Request 0 */
#define SRC_ID_GTMMSC61			861	/* GTM MCS6 Shared Service Request 1 */
#define SRC_ID_GTMMSC62			862	/* GTM MCS6 Shared Service Request 2 */
#define SRC_ID_GTMMSC63			863	/* GTM MCS6 Shared Service Request 3 */
#define SRC_ID_GTMMSC64			864	/* GTM MCS6 Shared Service Request 4 */
#define SRC_ID_GTMMSC65			865	/* GTM MCS6 Shared Service Request 5 */
#define SRC_ID_GTMMSC66			866	/* GTM MCS6 Shared Service Request 6 */
#define SRC_ID_GTMMSC67			867	/* GTM MCS6 Shared Service Request 7 */
#define SRC_ID_GTMMSC70			868	/* GTM MCS7 Shared Service Request 0 */
#define SRC_ID_GTMMSC71			869	/* GTM MCS7 Shared Service Request 1 */
#define SRC_ID_GTMMSC72			870	/* GTM MCS7 Shared Service Request 2 */
#define SRC_ID_GTMMSC73			871	/* GTM MCS7 Shared Service Request 3 */
#define SRC_ID_GTMMSC74			872	/* GTM MCS7 Shared Service Request 4 */
#define SRC_ID_GTMMSC75			873	/* GTM MCS7 Shared Service Request 5 */
#define SRC_ID_GTMMSC76			874	/* GTM MCS7 Shared Service Request 6 */
#define SRC_ID_GTMMSC77			875	/* GTM MCS7 Shared Service Request 7 */
#define SRC_ID_GTMMSC80			876	/* GTM MCS8 Shared Service Request 0 */
#define SRC_ID_GTMMSC81			877	/* GTM MCS8 Shared Service Request 1 */
#define SRC_ID_GTMMSC82			878	/* GTM MCS8 Shared Service Request 2 */
#define SRC_ID_GTMMSC83			879	/* GTM MCS8 Shared Service Request 3 */
#define SRC_ID_GTMMSC84			880	/* GTM MCS8 Shared Service Request 4 */
#define SRC_ID_GTMMSC85			881	/* GTM MCS8 Shared Service Request 5 */
#define SRC_ID_GTMMSC86			882	/* GTM MCS8 Shared Service Request 6 */
#define SRC_ID_GTMMSC87			883	/* GTM MCS8 Shared Service Request 7 */
#define SRC_ID_GTMMSC90			884	/* GTM MCS9 Shared Service Request 0 */
#define SRC_ID_GTMMSC91			885	/* GTM MCS9 Shared Service Request 1 */
#define SRC_ID_GTMMSC92			886	/* GTM MCS9 Shared Service Request 2 */
#define SRC_ID_GTMMSC93			887	/* GTM MCS9 Shared Service Request 3 */
#define SRC_ID_GTMMSC94			888	/* GTM MCS9 Shared Service Request 4 */
#define SRC_ID_GTMMSC95			889	/* GTM MCS9 Shared Service Request 5 */
#define SRC_ID_GTMMSC96			890	/* GTM MCS9 Shared Service Request 6 */
#define SRC_ID_GTMMSC97			891	/* GTM MCS9 Shared Service Request 7 */

#define SRC_ID_GTMTOM00			900	/* GTM TOM0 Shared Service Request 0 */
#define SRC_ID_GTMTOM01			901	/* GTM TOM0 Shared Service Request 1 */
#define SRC_ID_GTMTOM02			902	/* GTM TOM0 Shared Service Request 2 */
#define SRC_ID_GTMTOM03			903	/* GTM TOM0 Shared Service Request 3 */
#define SRC_ID_GTMTOM04			904	/* GTM TOM0 Shared Service Request 4 */
#define SRC_ID_GTMTOM05			905	/* GTM TOM0 Shared Service Request 5 */
#define SRC_ID_GTMTOM06			906	/* GTM TOM0 Shared Service Request 6 */
#define SRC_ID_GTMTOM07			907	/* GTM TOM0 Shared Service Request 7 */
#define SRC_ID_GTMTOM10			908	/* GTM TOM1 Shared Service Request 0 */
#define SRC_ID_GTMTOM11			909	/* GTM TOM1 Shared Service Request 1 */
#define SRC_ID_GTMTOM12			910	/* GTM TOM1 Shared Service Request 2 */
#define SRC_ID_GTMTOM13			911	/* GTM TOM1 Shared Service Request 3 */
#define SRC_ID_GTMTOM14			912	/* GTM TOM1 Shared Service Request 4 */
#define SRC_ID_GTMTOM15			913	/* GTM TOM1 Shared Service Request 5 */
#define SRC_ID_GTMTOM16			914	/* GTM TOM1 Shared Service Request 6 */
#define SRC_ID_GTMTOM17			915	/* GTM TOM1 Shared Service Request 7 */
#define SRC_ID_GTMTOM20			916	/* GTM TOM2 Shared Service Request 0 */
#define SRC_ID_GTMTOM21			917	/* GTM TOM2 Shared Service Request 1 */
#define SRC_ID_GTMTOM22			918	/* GTM TOM2 Shared Service Request 2 */
#define SRC_ID_GTMTOM23			919	/* GTM TOM2 Shared Service Request 3 */
#define SRC_ID_GTMTOM24			920	/* GTM TOM2 Shared Service Request 4 */
#define SRC_ID_GTMTOM25			921	/* GTM TOM2 Shared Service Request 5 */
#define SRC_ID_GTMTOM26			922	/* GTM TOM2 Shared Service Request 6 */
#define SRC_ID_GTMTOM27			923	/* GTM TOM2 Shared Service Request 7 */
#define SRC_ID_GTMTOM30			924	/* GTM TOM3 Shared Service Request 0 */
#define SRC_ID_GTMTOM31			925	/* GTM TOM3 Shared Service Request 1 */
#define SRC_ID_GTMTOM32			926	/* GTM TOM3 Shared Service Request 2 */
#define SRC_ID_GTMTOM33			927	/* GTM TOM3 Shared Service Request 3 */
#define SRC_ID_GTMTOM34			928	/* GTM TOM3 Shared Service Request 4 */
#define SRC_ID_GTMTOM35			929	/* GTM TOM3 Shared Service Request 5 */
#define SRC_ID_GTMTOM36			930	/* GTM TOM3 Shared Service Request 6 */
#define SRC_ID_GTMTOM37			931	/* GTM TOM3 Shared Service Request 7 */
#define SRC_ID_GTMTOM40			932	/* GTM TOM4 Shared Service Request 0 */
#define SRC_ID_GTMTOM41			933	/* GTM TOM4 Shared Service Request 1 */
#define SRC_ID_GTMTOM42			934	/* GTM TOM4 Shared Service Request 2 */
#define SRC_ID_GTMTOM43			935	/* GTM TOM4 Shared Service Request 3 */
#define SRC_ID_GTMTOM44			936	/* GTM TOM4 Shared Service Request 4 */
#define SRC_ID_GTMTOM45			937	/* GTM TOM4 Shared Service Request 5 */
#define SRC_ID_GTMTOM46			938	/* GTM TOM4 Shared Service Request 6 */
#define SRC_ID_GTMTOM47			939	/* GTM TOM4 Shared Service Request 7 */
#define SRC_ID_GTMTOM50			940	/* GTM TOM5 Shared Service Request 0 */
#define SRC_ID_GTMTOM51			941	/* GTM TOM5 Shared Service Request 1 */
#define SRC_ID_GTMTOM52			942	/* GTM TOM5 Shared Service Request 2 */
#define SRC_ID_GTMTOM53			943	/* GTM TOM5 Shared Service Request 3 */
#define SRC_ID_GTMTOM54			944	/* GTM TOM5 Shared Service Request 4 */
#define SRC_ID_GTMTOM55			945	/* GTM TOM5 Shared Service Request 5 */
#define SRC_ID_GTMTOM56			946	/* GTM TOM5 Shared Service Request 6 */
#define SRC_ID_GTMTOM57			947	/* GTM TOM5 Shared Service Request 7 */

#define SRC_ID_GTMATOM00		956	/* GTM ATOM0 Shared Service Request 0 */
#define SRC_ID_GTMATOM01		957	/* GTM ATOM0 Shared Service Request 1 */
#define SRC_ID_GTMATOM02		958	/* GTM ATOM0 Shared Service Request 2 */
#define SRC_ID_GTMATOM03		959	/* GTM ATOM0 Shared Service Request 3 */
#define SRC_ID_GTMATOM10		960	/* GTM ATOM1 Shared Service Request 0 */
#define SRC_ID_GTMATOM11		961	/* GTM ATOM1 Shared Service Request 1 */
#define SRC_ID_GTMATOM12		962	/* GTM ATOM1 Shared Service Request 2 */
#define SRC_ID_GTMATOM13		963	/* GTM ATOM1 Shared Service Request 3 */
#define SRC_ID_GTMATOM20		964	/* GTM ATOM2 Shared Service Request 0 */
#define SRC_ID_GTMATOM21		965	/* GTM ATOM2 Shared Service Request 1 */
#define SRC_ID_GTMATOM22		966	/* GTM ATOM2 Shared Service Request 2 */
#define SRC_ID_GTMATOM23		967	/* GTM ATOM2 Shared Service Request 3 */
#define SRC_ID_GTMATOM30		968	/* GTM ATOM3 Shared Service Request 0 */
#define SRC_ID_GTMATOM31		969	/* GTM ATOM3 Shared Service Request 1 */
#define SRC_ID_GTMATOM32		970	/* GTM ATOM3 Shared Service Request 2 */
#define SRC_ID_GTMATOM33		971	/* GTM ATOM3 Shared Service Request 3 */
#define SRC_ID_GTMATOM40		972	/* GTM ATOM4 Shared Service Request 0 */
#define SRC_ID_GTMATOM41		973	/* GTM ATOM4 Shared Service Request 1 */
#define SRC_ID_GTMATOM42		974	/* GTM ATOM4 Shared Service Request 2 */
#define SRC_ID_GTMATOM43		975	/* GTM ATOM4 Shared Service Request 3 */
#define SRC_ID_GTMATOM50		976	/* GTM ATOM5 Shared Service Request 0 */
#define SRC_ID_GTMATOM51		977	/* GTM ATOM5 Shared Service Request 1 */
#define SRC_ID_GTMATOM52		978	/* GTM ATOM5 Shared Service Request 2 */
#define SRC_ID_GTMATOM53		979	/* GTM ATOM5 Shared Service Request 3 */
#define SRC_ID_GTMATOM60		980	/* GTM ATOM6 Shared Service Request 0 */
#define SRC_ID_GTMATOM61		981	/* GTM ATOM6 Shared Service Request 1 */
#define SRC_ID_GTMATOM62		982	/* GTM ATOM6 Shared Service Request 2 */
#define SRC_ID_GTMATOM63		983	/* GTM ATOM6 Shared Service Request 3 */
#define SRC_ID_GTMATOM70		984	/* GTM ATOM7 Shared Service Request 0 */
#define SRC_ID_GTMATOM71		985	/* GTM ATOM7 Shared Service Request 1 */
#define SRC_ID_GTMATOM72		986	/* GTM ATOM7 Shared Service Request 2 */
#define SRC_ID_GTMATOM73		987	/* GTM ATOM7 Shared Service Request 3 */
#define SRC_ID_GTMATOM80		988	/* GTM ATOM8 Shared Service Request 0 */
#define SRC_ID_GTMATOM81		989	/* GTM ATOM8 Shared Service Request 1 */
#define SRC_ID_GTMATOM82		990	/* GTM ATOM8 Shared Service Request 2 */
#define SRC_ID_GTMATOM83		991	/* GTM ATOM8 Shared Service Request 3 */
#define SRC_ID_GTMATOM90		992	/* GTM ATOM9 Shared Service Request 0 */
#define SRC_ID_GTMATOM91		993	/* GTM ATOM9 Shared Service Request 1 */
#define SRC_ID_GTMATOM92		994	/* GTM ATOM9 Shared Service Request 2 */
#define SRC_ID_GTMATOM93		995	/* GTM ATOM9 Shared Service Request 3 */
#define SRC_ID_GTMATOM100		996	/* GTM ATOM10 Shared Service Request 0 */
#define SRC_ID_GTMATOM101		997	/* GTM ATOM10 Shared Service Request 1 */
#define SRC_ID_GTMATOM102		998	/* GTM ATOM10 Shared Service Request 2 */
#define SRC_ID_GTMATOM103		999	/* GTM ATOM10 Shared Service Request 3 */
#define SRC_ID_GTMATOM110		1000	/* GTM ATOM11 Shared Service Request 0 */
#define SRC_ID_GTMATOM111		1001	/* GTM ATOM11 Shared Service Request 1 */
#define SRC_ID_GTMATOM112		1002	/* GTM ATOM11 Shared Service Request 2 */
#define SRC_ID_GTMATOM113		1003	/* GTM ATOM11 Shared Service Request 3 */

#define SRC_ID_GTMMCSW0			1012	/* GTM Multi Channel Sequencer Service Request 0 */
#define SRC_ID_GTMMCSW1			1013	/* GTM Multi Channel Sequencer Service Request 1 */
#define SRC_ID_GTMMCSW2			1014	/* GTM Multi Channel Sequencer Service Request 2 */
#define SRC_ID_GTMMCSW3			1015	/* GTM Multi Channel Sequencer Service Request 3 */
#define SRC_ID_GTMMCSW4			1016	/* GTM Multi Channel Sequencer Service Request 4 */
#define SRC_ID_GTMMCSW5			1017	/* GTM Multi Channel Sequencer Service Request 5 */
#define SRC_ID_GTMMCSW6			1018	/* GTM Multi Channel Sequencer Service Request 6 */
#define SRC_ID_GTMMCSW7			1019	/* GTM Multi Channel Sequencer Service Request 7 */
#define SRC_ID_GTMMCSW8			1020	/* GTM Multi Channel Sequencer Service Request 8 */
#define SRC_ID_GTMMCSW9			1021	/* GTM Multi Channel Sequencer Service Request 9 */

#define IRQ_ID_MAX_NUM			1022


#endif /* __INTIDS_TC39XA_H__ */
