/*
 * tricoreIRAM.x -- TC39xx memory description
 *   (using only internal RAM for code and data)
 *
 * Copyright HighTec EDV-Systeme GmbH 1982-2018
 */

OUTPUT_FORMAT("elf32-tricore")
OUTPUT_ARCH(tricore)
ENTRY(_start)

__TRICORE_DERIVATE_MEMORY_MAP__ = 0x3900;

 /* the symbol __TRICORE_DERIVATE_NAME__ will be defined in the crt0_tc39x.c and is
  * tested here to confirm that this memory map and the startup file will fit together
  */
  _. = ASSERT ((__TRICORE_DERIVATE_MEMORY_MAP__ == __TRICORE_DERIVATE_NAME__), "Using wrong Memory Map. This Map is for TC39XX");

/* minimal heap size (C library stuff) */
__HEAP_SIZE = DEFINED (__HEAP_SIZE) ? __HEAP_SIZE : 16K;

MEMORY
{
/* internal flash memories */
  /* one flash bank for all cores */
  int_flash  (rx):   org = 0x80000000, len = 3M
  /* core specific flash banks */
  int_flash0 (rxc0): org = 0x80000000, len = 3M
  int_flash1 (rxc1): org = 0x80300000, len = 3M
  int_flash2 (rxc2): org = 0x80600000, len = 3M
  int_flash3 (rxc3): org = 0x80900000, len = 3M
  int_flash4 (rxc4): org = 0x80c00000, len = 3M
  int_flash5 (rxc5): org = 0x80f00000, len = 1M

/* ED (emulation device) memory */
  ed_emem0 (rx):  org = 0x99000000, len = 1M
  ed_emem1 (rx):  org = 0x99100000, len = 1M
  ed_emem2 (rx):  org = 0x99200000, len = 1M
  ed_emem3 (rx):  org = 0x99300000, len = 1M

/* internal code ram */
  int_psprcpu0 (rxc0): org = 0xc0000000, len = 64K
  int_psprcpu1 (rxc1): org = 0xc0000000, len = 64K
  int_psprcpu2 (rxc2): org = 0xc0000000, len = 64K
  int_psprcpu3 (rxc3): org = 0xc0000000, len = 64K
  int_psprcpu4 (rxc4): org = 0xc0000000, len = 64K
  int_psprcpu5 (rxc5): org = 0xc0000000, len = 64K

/* internal data ram */
  int_dsprcpu0 (wc0!x): org = 0xd0000000, len = 96K
  int_dsprcpu1 (wc1!x): org = 0xd0000000, len = 96K
  int_dsprcpu2 (wc2!x): org = 0xd0000000, len = 96K
  int_dsprcpu3 (wc3!x): org = 0xd0000000, len = 96K
  int_dsprcpu4 (wc4!x): org = 0xd0000000, len = 96K
  int_dsprcpu5 (wc5!x): org = 0xd0000000, len = 96K

/* global view on internal memories */
  glb_int_psprcpu0 (rx):  org = 0x70100000, len = 64K
  glb_int_psprcpu1 (rx):  org = 0x60100000, len = 64K
  glb_int_psprcpu2 (rx):  org = 0x50100000, len = 64K
  glb_int_psprcpu3 (rx):  org = 0x40100000, len = 64K
  glb_int_psprcpu4 (rx):  org = 0x30100000, len = 64K
  glb_int_psprcpu5 (rx):  org = 0x10100000, len = 64K
  glb_int_dsprcpu0 (w!x): org = 0x70000000, len = 96K
  glb_int_dsprcpu1 (w!x): org = 0x60000000, len = 96K
  glb_int_dsprcpu2 (w!x): org = 0x50000000, len = 96K
  glb_int_dsprcpu3 (w!x): org = 0x40000000, len = 96K
  glb_int_dsprcpu4 (w!x): org = 0x30000000, len = 96K
  glb_int_dsprcpu5 (w!x): org = 0x10000000, len = 96K

/* for shared fast code */
  int_pspr (rx): org = 0xc0000000, len = 64K

/* for cloned data */
  int_dspr (w!x): org = 0xd0000000, len = 96K

/* LMU RAM partitions */
  lmu_dlmu_cpu0 (wxc0): org = 0x90000000, len = 64K
  lmu_dlmu_cpu1 (wxc1): org = 0x90010000, len = 64K
  lmu_dlmu_cpu2 (wxc2): org = 0x90020000, len = 64K
  lmu_dlmu_cpu3 (wxc3): org = 0x90030000, len = 64K
  /* A step: LMU_TC.002 ==> only lmu0_lmuram implemented */
  lmu0_lmuram (wx):     org = 0x90040000, len = 256K
  lmu1_lmuram (wx):     org = 0x90080000, len = 256K
  lmu2_lmuram (wx):     org = 0x900c0000, len = 256K
  lmu3_lmuram (wx):     org = 0x90100000, len = 256K
  lmu_dlmu_cpu4 (wxc4): org = 0x90140000, len = 64K
  lmu_dlmu_cpu5 (wxc5): org = 0x90150000, len = 64K
/* Default Application Memory (LMU_DAM_SRAM) */
  lmu_dam0_sram0 (wx):  org = 0x90400000, len = 32K
  lmu_dam0_sram1 (wx):  org = 0x90408000, len = 32K
  lmu_dam1_sram0 (wx):  org = 0x90410000, len = 32K
  lmu_dam1_sram1 (wx):  org = 0x90418000, len = 32K
}

/* map local memory address to the corresponding global address */
REGION_MAP("CPU0", ORIGIN(int_dsprcpu0), LENGTH(int_dsprcpu0), ORIGIN(glb_int_dsprcpu0))
REGION_MAP("CPU1", ORIGIN(int_dsprcpu1), LENGTH(int_dsprcpu1), ORIGIN(glb_int_dsprcpu1))
REGION_MAP("CPU2", ORIGIN(int_dsprcpu2), LENGTH(int_dsprcpu2), ORIGIN(glb_int_dsprcpu2))
REGION_MAP("CPU3", ORIGIN(int_dsprcpu3), LENGTH(int_dsprcpu3), ORIGIN(glb_int_dsprcpu3))
REGION_MAP("CPU4", ORIGIN(int_dsprcpu4), LENGTH(int_dsprcpu4), ORIGIN(glb_int_dsprcpu4))
REGION_MAP("CPU5", ORIGIN(int_dsprcpu5), LENGTH(int_dsprcpu5), ORIGIN(glb_int_dsprcpu5))
REGION_MAP("CPU0", ORIGIN(int_psprcpu0), LENGTH(int_psprcpu0), ORIGIN(glb_int_psprcpu0))
REGION_MAP("CPU1", ORIGIN(int_psprcpu1), LENGTH(int_psprcpu1), ORIGIN(glb_int_psprcpu1))
REGION_MAP("CPU2", ORIGIN(int_psprcpu2), LENGTH(int_psprcpu2), ORIGIN(glb_int_psprcpu2))
REGION_MAP("CPU3", ORIGIN(int_psprcpu3), LENGTH(int_psprcpu3), ORIGIN(glb_int_psprcpu3))
REGION_MAP("CPU4", ORIGIN(int_psprcpu4), LENGTH(int_psprcpu4), ORIGIN(glb_int_psprcpu4))
REGION_MAP("CPU5", ORIGIN(int_psprcpu5), LENGTH(int_psprcpu5), ORIGIN(glb_int_psprcpu5))

/* mirror regions with same physical memory */
REGION_MIRROR("glb_int_dsprcpu0", "int_dsprcpu0", "int_dspr")
REGION_MIRROR("glb_int_dsprcpu1", "int_dsprcpu1", "int_dspr")
REGION_MIRROR("glb_int_dsprcpu2", "int_dsprcpu2", "int_dspr")
REGION_MIRROR("glb_int_dsprcpu3", "int_dsprcpu3", "int_dspr")
REGION_MIRROR("glb_int_dsprcpu4", "int_dsprcpu4", "int_dspr")
REGION_MIRROR("glb_int_dsprcpu5", "int_dsprcpu5", "int_dspr")
REGION_MIRROR("glb_int_psprcpu0", "int_psprcpu0", "int_pspr")
REGION_MIRROR("glb_int_psprcpu1", "int_psprcpu1", "int_pspr")
REGION_MIRROR("glb_int_psprcpu2", "int_psprcpu2", "int_pspr")
REGION_MIRROR("glb_int_psprcpu3", "int_psprcpu3", "int_pspr")
REGION_MIRROR("glb_int_psprcpu4", "int_psprcpu4", "int_pspr")
REGION_MIRROR("glb_int_psprcpu5", "int_psprcpu5", "int_pspr")

/* Use alias for memory regions */
REGION_ALIAS("CODE_MEM", glb_int_psprcpu0)
REGION_ALIAS("FASTCODE_MEM", int_pspr)
REGION_ALIAS("FASTCODE_MEM_CPU0_", int_psprcpu0)
REGION_ALIAS("FASTCODE_MEM_CPU1_", int_psprcpu1)
REGION_ALIAS("FASTCODE_MEM_CPU2_", int_psprcpu2)
REGION_ALIAS("FASTCODE_MEM_CPU3_", int_psprcpu3)
REGION_ALIAS("FASTCODE_MEM_CPU4_", int_psprcpu4)
REGION_ALIAS("FASTCODE_MEM_CPU5_", int_psprcpu5)

REGION_ALIAS("RODATA_MEM", glb_int_psprcpu0)
REGION_ALIAS("GLOB_DATA", lmu0_lmuram)

REGION_ALIAS("CLONEDSDATA_MEM", int_dspr)

REGION_ALIAS("CSA_CPU0_",   int_dsprcpu0)
REGION_ALIAS("DATA_CPU0_",  int_dsprcpu0)
REGION_ALIAS("SDATA_CPU0_", int_dsprcpu0)
REGION_ALIAS("ZDATA_CPU0_", int_dsprcpu0)
REGION_ALIAS("BSS_CPU0_",   int_dsprcpu0)

REGION_ALIAS("CSA_CPU1_",   int_dsprcpu1)
REGION_ALIAS("DATA_CPU1_",  int_dsprcpu1)
REGION_ALIAS("SDATA_CPU1_", int_dsprcpu1)
REGION_ALIAS("ZDATA_CPU1_", int_dsprcpu1)
REGION_ALIAS("BSS_CPU1_",   int_dsprcpu1)

REGION_ALIAS("CSA_CPU2_",   int_dsprcpu2)
REGION_ALIAS("DATA_CPU2_",  int_dsprcpu2)
REGION_ALIAS("SDATA_CPU2_", int_dsprcpu2)
REGION_ALIAS("ZDATA_CPU2_", int_dsprcpu2)
REGION_ALIAS("BSS_CPU2_",   int_dsprcpu2)

REGION_ALIAS("CSA_CPU3_",   int_dsprcpu3)
REGION_ALIAS("DATA_CPU3_",  int_dsprcpu3)
REGION_ALIAS("SDATA_CPU3_", int_dsprcpu3)
REGION_ALIAS("ZDATA_CPU3_", int_dsprcpu3)
REGION_ALIAS("BSS_CPU3_",   int_dsprcpu3)

REGION_ALIAS("CSA_CPU4_",   int_dsprcpu4)
REGION_ALIAS("DATA_CPU4_",  int_dsprcpu4)
REGION_ALIAS("SDATA_CPU4_", int_dsprcpu4)
REGION_ALIAS("ZDATA_CPU4_", int_dsprcpu4)
REGION_ALIAS("BSS_CPU4_",   int_dsprcpu4)

REGION_ALIAS("CSA_CPU5_",   int_dsprcpu5)
REGION_ALIAS("DATA_CPU5_",  int_dsprcpu5)
REGION_ALIAS("SDATA_CPU5_", int_dsprcpu5)
REGION_ALIAS("ZDATA_CPU5_", int_dsprcpu5)
REGION_ALIAS("BSS_CPU5_",   int_dsprcpu5)

/* Include section description */
INCLUDE tricoreSections.lsf
