/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          ---------------------------------------------------------          *
*                                                                             *
* Filename : efs_debug.h                                                      *
* Description : Headerfile for efs_debug.c                                    *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                    (c)2005 Lennart Yseboody *
*                                                    (c)2005 Michael De Nil   *
*                             LPC2000 ARM7 Interface (c)2005 Martin Thomas    *
*                             AT91    ARM7 Interface (c)2005 Martin Thomas    *
\*****************************************************************************/

#ifndef __EFS_DEBUG_H__
#define __EFS_DEBUG_H__

/*****************************************************************************/
#include "efs_types.h"
/*****************************************************************************/

#ifndef DEBUG
	#define TXT(x) ;
	#define DBG(x) ;
	#define FUNC_IN(x) ;
	#define FUNC_OUT(x) ;
#endif /* !DEBUG */

#ifdef DEBUG
	#if defined(HW_ENDPOINT_LINUX) || defined(HW_ENDPOINT_LINUX64)
		#define HW_ENDPOINT_LINUX_ALL
	#endif

	#ifdef HW_ENDPOINT_ATMEGA128_SD
		#include <avr/io.h>
		#include <compat/ina90.h>
		#include <avr/pgmspace.h>
		#include <stdio.h>

		#define TXT(x) PSTR(x)
		#define DBG(x) debug x
		#define FUNC_IN(x) ;
		#define FUNC_OUT(x) ;
	#endif

	#ifdef HW_ENDPOINT_LINUX_ALL
		#include <stdio.h>
		#include <stdarg.h>

		#define TXT(x) x
		#define DBG(x) debug x
		#define FUNC_IN(x) debug_funcin(x)
		#define FUNC_OUT(x) debug_funcout(x)
	#endif

	#ifdef HW_ENDPOINT_DSP_TI6713_SD
		#include <stdio.h>
		#include <stdarg.h>

		#define TXT(x) x
		#define DBG(x) printf x
		#define FUNC_IN(x) ;
		#define FUNC_OUT(x) ;
	#endif

	#if defined(HW_ENDPOINT_LPC2000_SD) || defined (HW_ENDPOINT_AT91_SD) || defined (HW_ENDPOINT_AT91_MCI) || defined(HW_ENDPOINT_SPI_SD) || defined(HW_ENDPOINT_STM32_SDIO) || defined(HW_ENDPOINT_AT91_HSMCI)
		#include "interfaces/efsl_dbg_printf.h"

		#define TXT(x) x
		#define DBG(x) debug x
		#define FUNC_IN(x) ;
		#define FUNC_OUT(x) ;
		#define debug efsl_debug_printf
	#else
	void debug(const eint8 *format, ...);
	#endif

	void debug_init(void);
	void debug_end(void);

	#ifdef HW_ENDPOINT_LINUX_ALL
	FILE *debugfile;
	volatile euint8 tw;
	void debug_funcin(const eint8 *format, ...);
	void debug_funcout(const eint8 *format, ...);
	euint8 debug_getByte();
	euint8 debug_getString(euint8 *data, euint16 length);
	#endif

	#ifdef HW_ENDPOINT_ATMEGA128_SD
	void debug_initUART(euint16 baudrate);
	void debug_sendByte(euint8 data);
	#endif

#endif /* DEBUG */

#endif /* __EFS_DEBUG_H__ */
