/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          --------------------- -----------------------------------          *
*                                                                             *
* Filename :  sd_spi.h                                                        *
* Description : Headerfile for SPI connected interfaces                       *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                                             *
*                                                    (c)2005 Michael De Nil   *
*                                                    (c)2005 Lennart Yseboodt *
\*****************************************************************************/

#ifndef __SD_SPI_H__
#define __SD_SPI_H__

#include "efs_types.h"

/*************************************************************\
              hwInterface
               ----------
* long		sectorCount		Number of sectors on the file.
\*************************************************************/
struct  hwInterface
{
	euint32	sectorCount;	/* number of sectors on SD card */
	euint32	cardRCA;		/* Relative Card Address (needed for SD cards) */
	eint32	cardSDHC;		/* SD High Capacity with block addressing */
};
typedef struct hwInterface hwInterface;

esint8 if_initInterface(hwInterface *file, eint8 *opts);
esint8 if_readBuf(hwInterface *file, euint32 address, euint8 *buf);
esint8 if_writeBuf(hwInterface *file, euint32 address, euint8 *buf);
esint8 if_setPos(hwInterface *file, euint32 address);

void if_spiInit(hwInterface *iface);
void if_spiSetSpeed(euint8 speed);
euint8 if_spiSend(hwInterface *iface, euint8 outgoing);

#endif /* __SD_SPI_H__ */
