/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          --------------------- -----------------------------------          *
*                                                                             *
* Filename : efs_disc.c                                                       *
* Description : This file contains the functions regarding the whole disc     *
*               such as loading the MBR and performing read/write tests.      *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                    (c)2004 Lennart Yseboodt *
*                                                    (c)2004 Michael De Nil   *
\*****************************************************************************/

/*****************************************************************************/
#include "efs_disc.h"
#include "efs_extract.h"
#include "efs_plibc.h"
/*****************************************************************************/

/*****************************************************************************/

/* ****************************************************************************
 * esint8 disc_loadMBR(Disc *disc)
 * Description: This functions copies the partitiontable to the partitions field.
 * Return value: 0 on success and <0 on failure.
*/
static esint8 disc_loadMBR(Disc *disc)
{
	euint8 x;
	euint8 *buf;
	euint32 offset;
	PartitionField *pf;

	buf = ioman_getSector(disc->ioman, LBA_ADDR_MBR, IOM_MODE_READONLY | IOM_MODE_EXP_REQ);
	if (buf == (euint8 *)0)
		return -4;

	if ((buf[0x1FE] != 0x55) || (buf[0x1FF] != 0xAA))
		return -5;

	x = sizeof(disc->partitions) / sizeof(disc->partitions[0]);
	pf = disc->partitions;
	offset = PARTITION_TABLE_OFFSET;
	do
	{
		ex_getPartitionField(buf, pf, offset);
		if ((pf->bootFlag & 0x7F) != 0x00)
		{
			/* Non valid partition found, assume whole table is junk */
			memClr(disc->partitions, sizeof(disc->partitions));
			break;
		}
		offset += SIZE_PARTITION_FIELD;
		pf++;
	} while (--x);

	if (disc->partitions[0].numSectors == 0)
	{
		euint32 numsect;
		numsect = ex_getb16(buf, 0x13);		/* Total sectors (16 bit - if zero then use 0x20) */
		if (numsect == 0)
		{
			numsect = ex_getb32(buf, 0x20);	/* Need the 32 bit one! */
		}
		disc->partitions[0].numSectors = numsect;
	}

	ioman_releaseSector(disc->ioman, buf);
	return 0;
}
/*****************************************************************************/

/* ****************************************************************************
 * esint8 disc_initDisc(Disc *disc, hcInterface *source)
 * Description: This initialises the disc by loading the MBR and setting the
 * pointer to the hardware object.
*/
esint8 disc_initDisc(Disc *disc, IOManager *ioman)
{
	disc->ioman = ioman;
	disc_setError(disc, DISC_NOERROR);
	return disc_loadMBR(disc);
}
