/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          --------------------- -----------------------------------          *
*                                                                             *
* Filename : efs_mkfs.c                                                       *
* Description : These functions are used for creating an empty filesystem.    *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                    (c)2005 Michael De Nil   *
*                                                    (c)2005 Lennart Yseboodt *
\*****************************************************************************/

/*****************************************************************************/
#include "efs_mkfs.h"
#include "efs_debug.h"
#include "efs_plibc.h"
#include "efs_extract.h"
/*****************************************************************************/

signed short mkfs_makevfat(Partition *part)
{
	unsigned long c, cc, ret;
	unsigned long ns, fs, ds, dc;
	unsigned char buf[512];

	ns=part->disc->partitions[part->activePartition].numSectors;

	if (ns < 66581)
	{
		DBG((TXT("This is not possible due to insufficient sectors. Sorry\n")));
		return MKFS_ERR_TOOLITTLESECTORS;
	}

	ret = 0;

	for (c = 1<<6; c >= 1; c >>= 1)
	{

		/* First guess */
		ds = ns - 32;
		fs = ((ds/c)+127)/128;
		/* ds was guess too large, so fs is too large now too. */

		for (cc = 0; cc < 2; cc++)
		{

			/* Round 2, error round */
			ds = ns - 32 - 2*fs;
			fs = ((ds/c)+127)/128;
			/* Since fs was too large, ds became too small. So the fs for this small ds is too small as well. */

			/* Round 3, correction round */
			ds = ns - 32 - 2*fs;
			fs = ((ds/c)+127)/128;
			/* The fs was too small, so ds was too large. The calculated fs should be slightly too large. */

		}

		/* Round 4, finalise */
		ds = ns - 32 - 2*fs;

		dc = ds / c;
		if (ret < (fs*128-dc)/128)
			ret = (fs*128-dc)/128;

		/* Check if with current setting we have a valid fat ? */

		if (dc >= 65525 + 16)
		{
			break;
		}
	}

	/* Generate BPB */
	memClr(buf, 512);

	/* Boot code */
	buf[0] = 0xE9;
	buf[1] = 0x00;
	buf[2] = 0x00; /* RESET */

	/* OEM name */
	memCpy("DSCOSMSH", buf+3, 8);


/*
	WT 2006-06-15
	the following stuff does not work on targets which have
	not defined BYTE_ALIGNMENT!!
 */

	/* Bytes/Sector */
#if 0
	*((unsigned short *)(buf+11)) = 512;
#else
	ex_setb16(buf, 11, 512);
#endif

	/* Sectors/Cluster */
	buf[13] = (unsigned char)c;

	/* Reserved Sectors */
#if 0
	*((unsigned short *)(buf+14)) = 32;
#else
	ex_setb16(buf, 13, 42);
#endif

	/* Number of FAT Tables */
	buf[16] = 2;

	/* RootEntryCount */
#if 0
	*((unsigned short *)(buf+17)) = 0;
#else
	ex_setb16(buf, 17, 0);
#endif

	/* Total Sector Count __16 */
#if 0
	*((unsigned short *)(buf+19)) = 0;
#else
	ex_setb16(buf, 19, 0);
#endif

	/* Media (crap) */
	buf[21] = 0xF8;

	/* FAT size 16 */
#if 0
	*((unsigned short *)(buf+22)) = 0;
#else
	ex_setb16(buf, 22, 0);
#endif

	/* Total Sector Count __32 */
#if 0
	*((unsigned long *)(buf+32)) = ns;
#else
	ex_setb32(buf, 32, ns);
#endif

	/* Fat Size 32 */
#if 0
	*((unsigned long *)(buf+36)) = fs;
#else
	ex_setb32(buf, 36, fs);
#endif

	/* First Cluster Root Dir */
#if 0
	*((unsigned long *)(buf+44)) = 2;
#else
	ex_setb32(buf, 44, 2);
#endif

	/* VolumeID */
#if 0
	*((unsigned long *)(buf+67)) = 0x13371337;
#else
	ex_setb32(buf, 67, 0x13371337);
#endif

	/* Volume Label */
	memCpy("DISCOSMASH!", buf+71, 11);

	/* Filesystemtype */
	memCpy("FAT32   ", buf+82, 8);

	/* Magic */
	buf[510] = 0x55;
	buf[511] = 0xAA;

	part_writeBuf(part, 0, buf);

	memClr(buf, 512);
	for (c = 32; c < (32+2*fs); c++)
	{
		part_writeBuf(part, c, buf);
	}
#if 0
	*(((unsigned long *)buf)  )=0x0FFFFFF8;
	*(((unsigned long *)buf)+1)=0x0FFFFFFF;
	*(((unsigned long *)buf)+2)=0x0FFFFFF8;
#else
	ex_setb32(buf, 0, 0x0FFFFFF8);
	ex_setb32(buf, 4, 0x0FFFFFFF);
	ex_setb32(buf, 8, 0x0FFFFFF8);
#endif
	part_writeBuf(part, 32, buf);
	part_writeBuf(part, 32+fs, buf);

	return 0;
}
