/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          --------------------- -----------------------------------          *
*                                                                             *
* Filename :  efs_time.c                                                      *
* Description : This file contains functions for time support                 *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                    (c)2005 Michael De Nil   *
*                                                    (c)2005 Lennart Yseboodt *
\*****************************************************************************/

/*****************************************************************************/
#include "efs_time.h"
/*****************************************************************************/


#ifdef DATE_TIME_SUPPORT
euint8 fs_makeTimeDate(const efsl_real_time_t *time_now, euint16 *time, euint16 *date)
{
	euint8 rc;
	euint8 d, s, m, h;
	euint16 y;
	efsl_real_time_t current_time;

	if (time_now == NULL)
	{
		time_now = (efsl_real_time_t *)&current_time;
		rc = efsl_getLocalTime(&current_time);
		if (rc)
		{
			*time = 0;
			*date = 0;
			return rc;
		}
	}

	s = time_now->seconds;
	m = time_now->minutes;
	h = time_now->hours;

	*time = ((h > 23 ? 0 : (h & 0x1F) << 11)
		  |  (m > 59 ? 0 : (m & 0x3F) << 5)
		  |  (s > 59 ? 0 : (s >> 1) & 0x1F));

	d = time_now->day;
	m = time_now->month;
	y = time_now->year - 1980;

	*date = ((y > 127 ? 127 << 9 : (y & 0x7F) << 9)
		  | ((m == 0 || m > 12) ? (1 << 5) : (m & 0xF) << 5)
		  | ((d == 0 || d > 31) ? 1 : (d & 0x1F)));

	return 0;
}

/*****************************************************************************/

void fs_unpackTimeDate(efsl_real_time_t *time_date, euint16 time, euint16 date)
{
    euint16 c;

    time_date->seconds = (time & 0x1F) * 2;
    time_date->minutes = (time >> 5) & 0x3F;
    time_date->hours   = (time >> 11) & 0x1F;

    c = date & 0x1F;
    if (c == 0)
        c++;
    time_date->day = (euint8)c;

    c = (date >> 5) & 0x0F;
    if (c == 0)
        c++;
    time_date->month = (euint8)c;

    time_date->year = ((date >> 9) & 0x7F) + 1980;
}

/*****************************************************************************/

/* time support for target */
struct _DateTime;

extern int GetDateTime(struct _DateTime *date);

euint8 efsl_getLocalTime(efsl_real_time_t *buf)
{
	int res = GetDateTime((struct _DateTime *)buf);
	return (euint8)(res == 0);
}
#endif /* DATE_TIME_SUPPORT */
/*****************************************************************************/
