/*****************************************************************************\
*              efs - General purpose Embedded Filesystem library              *
*          ---------------------------------------------------------          *
*                                                                             *
* Filename : sd_spi.c                                                         *
* Description : This file contains the functions needed to use efs for        *
*               accessing files on an SD-card connected over SPI              *
*                                                                             *
* This library is free software; you can redistribute it and/or               *
* modify it under the terms of the GNU Lesser General Public                  *
* License as published by the Free Software Foundation; either                *
* version 2.1 of the License, or (at your option) any later version.          *
*                                                                             *
* This library is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of              *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           *
* Lesser General Public License for more details.                             *
*                                                                             *
*                                                    (c)2010 Willi Thei      *
*                                                                             *
\*****************************************************************************/

/*****************************************************************************/
#include "interfaces/sd_spi.h"
#include "interfaces/sd.h"
#include "efs_types.h"
#include "efs_debug.h"
/*****************************************************************************/

/* macro for avoiding warnings about unused function arguments */
#define NOT_USED(x)		(void)(x)


esint8 if_initInterface(hwInterface *file, eint8 *opts)
{
	euint32 sc;

	NOT_USED(opts);

	if_spiInit(file);

	if (sd_Init(file) < 0)
	{
		DBG((TXT("Card failed to init, breaking up...\n")));
		return -1;
	}

	if (sd_State(file) < 0)
	{
		DBG((TXT("Card didn't return the ready state, breaking up...\n")));
		return -2;
	}

	sd_getDriveSize(file, &sc);
	file->sectorCount = sc / 512;
	if ((sc % 512) != 0)
	{
		file->sectorCount--;
	}
	DBG((TXT("Card Capacity is %lu Bytes (%lu Sectors)\n"), sc, file->sectorCount));

	/* set faster speed on SPI interface */
	if_spiSetSpeed(0);

	return 0;
}
/*****************************************************************************/

esint8 if_readBuf(hwInterface *file, euint32 address, euint8 *buf)
{
	return sd_readSector(file, address, buf, 512);
}
/*****************************************************************************/

esint8 if_writeBuf(hwInterface *file, euint32 address, euint8 *buf)
{
	return sd_writeSector(file, address, buf);
}
/*****************************************************************************/

esint8 if_setPos(hwInterface *file, euint32 address)
{
	NOT_USED(file);
	NOT_USED(address);

	return 0;
}
/*****************************************************************************/
