/*====================================================================
* Project:  Board Support Package (BSP)
* Function: Transmit and receive characters via serial line
*           (interrupt and polling variant combined)
*
* Copyright HighTec EDV-Systeme GmbH 1982-2013
*====================================================================*/

#ifndef __RS232_H__
#define __RS232_H__

#ifdef __cplusplus
  extern "C" {
#endif /* __cplusplus */

/* Initialise asynchronous interface to operate at BAUDRATE,8,n,1 */
void _init_uart(int baudrate);

#if (NON_BLOCKING_SERIALIO > 0)
/* function API for interrupt variant */

/* send a buffer of given size <len> over serial line */
/* returns 1 if complete buffer can be sent, else 0 */
int _uart_send(const char *buffer, int len);

/* send a string over serial line */
/* returns 1 if complete string can be sent, else 0 */
int _uart_puts(const char *str);

/* get a character from serial line */
/* returns 1 and the character in *c if there is one, else 0 */
int _uart_getchar(char *c);

/* test UARTs sending state */
int _uart_sending(void);

#else
/* function API for polling variant */

/* Send the character chr via the serial line */
void _out_uart(const unsigned char chr);

/* Receive (and return) a character from the serial line */
unsigned char _in_uart(void);

/* Check the serial line if a character has been received */
/* returns 1 and the character in *chr if there is one, else 0 */
int _poll_uart(unsigned char *chr);

#endif /* NON_BLOCKING_SERIALIO */

#ifdef __cplusplus
  }
#endif /* __cplusplus */

#endif /* __RS232_H__ */
