/*====================================================================
* Project:  Board Support Package (BSP)
* Function: macros for handling different AURIX TC3x devices and boards
*
* Copyright HighTec EDV-Systeme GmbH 1982-2020
*====================================================================*/

#ifndef __TC_INC_PATH_H__
#define __TC_INC_PATH_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#if defined(__TC39XX__)
# if defined(TRIBOARD_TC39XA) || defined(APPKIT_TC397TFT) || defined(APPKIT_TC397TFT_ADAS) || defined(PHYCORE_TC39XA)
#  define TCPATH		tc39xa
#  define RUN_ON_TC39XA	1
#  define EMEM_OPTION	1	/* device with EMEM option */
# elif defined(TRIBOARD_TC39XB) || defined(PHYCORE_TC39XB) || defined(APPKIT_TC397B) || defined(APPKIT_TC397B_ADAS)
#  define TCPATH		tc39xb
#  define RUN_ON_TC39XA	0
#  define EMEM_OPTION	1	/* device with EMEM option */
# else
#  error "Unknown TC39x board"
# endif /* TRIBOARD_TC39XA || APPKIT_TC397TFT || APPKIT_TC397TFT_ADAS || PHYCORE_TC39XA */
#else
# error "Unsupported AURIX TC3x device"
#endif /* __TC39XX__ */

#define TC_STR(s)		# s
#define TC_INCLUDE(f)	TC_STR(f)

/* check for application kits */
#if defined(APPKIT_TC397TFT) || defined(APPKIT_TC397TFT_ADAS) || defined(APPKIT_TC397B) || defined(APPKIT_TC397B_ADAS)
# define RUN_ON_APPKIT	1
# if defined(APPKIT_TC397TFT_ADAS) || defined(APPKIT_TC397B_ADAS)
#  define ADAS_APPKIT	1
# else
#  define ADAS_APPKIT	0
# endif /* APPKIT_TC397TFT_ADAS */
#else
# define RUN_ON_APPKIT	0
#endif /* APPKIT_TC397TFT || APPKIT_TC397TFT_ADAS || APPKIT_TC397B || APPKIT_TC397B_ADAS */

/* check for phyCORE kits */
#if defined(PHYCORE_TC39XB) || defined(PHYCORE_TC39XA)
# define RUN_ON_PHYCORE	1
#else
# define RUN_ON_PHYCORE	0
#endif /* PHYCORE_TC39XB || PHYCORE_TC39XA */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __TC_INC_PATH_H__ */
