/*
 *
 *      lanw5300.h
 *
 *      WIZnet W5300 Ethernet chip
 *
 */

#ifndef __WIZNET_LANW5300_H__
#define __WIZNET_LANW5300_H__


/* Maximum socket number. W5300 supports max 8 channels. */
#define W5300_MAX_SOCK_NUM		8


/* register definitions (offset value relative to base address) */

#define W5300_MR			0x00	/* Mode Register */
#define W5300_IDM_AR		0x02	/* Indirect Mode Address Register */
#define W5300_IDM_DR		0x04	/* Indirect Mode Data Register */
#define W5300_IR			0x02	/* Interrupt Register */
#define W5300_IMR			0x04	/* Interrupt Mask Register */
#define W5300_RESERVED_0	0x06	/* reserved on W5300 */
#define W5300_SHAR			0x08	/* Source Hardware Address Register (0,1) */
#define W5300_SHAR2			0x0A	/* Source Hardware Address Register (2,3) */
#define W5300_SHAR4			0x0C	/* Source Hardware Address Register (4,5) */
#define W5300_RESERVED_1	0x0E	/* reserved on W5300 */
#define W5300_GAR			0x10	/* Gateway (IP) Address Register (0,1) */
#define W5300_GAR2			0x12	/* Gateway (IP) Address Register (2,3) */
#define W5300_SUBR			0x14	/* Subnet Mask Register (0,1) */
#define W5300_SUB2			0x16	/* Subnet Mask Register (2,3) */
#define W5300_SIPR			0x18	/* Source (IP) Address Register (0,1) */
#define W5300_SIPR2			0x1A	/* Source (IP) Address Register (2,3) */
#define W5300_RTR			0x1C	/* Retransmission Timeout-value Register */
#define W5300_RCR			0x1E	/* Retransmission Retry-count Register */
#define W5300_TMSR_01		0x20	/* Transmit Memory Size Register (Socket 0 + 1) */
#define W5300_TMSR_23		0x22	/* Transmit Memory Size Register (Socket 2 + 3) */
#define W5300_TMSR_45		0x24	/* Transmit Memory Size Register (Socket 4 + 5) */
#define W5300_TMSR_67		0x26	/* Transmit Memory Size Register (Socket 6 + 7) */
#define W5300_RMSR_01		0x28	/* Receive Memory Size Register (Socket 0 + 1) */
#define W5300_RMSR_23		0x2A	/* Receive Memory Size Register (Socket 2 + 3) */
#define W5300_RMSR_45		0x2C	/* Receive Memory Size Register (Socket 4 + 5) */
#define W5300_RMSR_67		0x2E	/* Receive Memory Size Register (Socket 6 + 7) */
#define W5300_MTYPER		0x30	/* Memory Block Type Register */
#define W5300_PATR			0x32	/* PPPoE Authentication Register */
#define W5300_PTIMER		0x36	/* PPP LCP Request Timer Register */
#define W5300_PMAGICR		0x38	/* PPP LCP Magic Number Register */
#define W5300_PSIDR			0x3C	/* PPP Session ID Register */
#define W5300_PDHAR			0x40	/* PPP Destination Hardware Address Register (0,1) */
#define W5300_PDHAR2		0x42	/* PPP Destination Address Register (2,3) */
#define W5300_PDHAR4		0x44	/* PPP Destination Address Register (4,5) */
#define W5300_UIPR			0x48	/* Unreachable IP Address Register (0,1) */
#define W5300_UIPR2			0x4A	/* Unreachable IP Address Register (2,3) */
#define W5300_UPORTR		0x4C	/* Unreachable Port Number Register */
#define W5300_FMTUR			0x4E	/* Fragment MTU Register */
#define W5300_P0_BRDYR		0x50	/* Pin "BRDY0" Configuration Register */
#define W5300_P0_BDPTHR		0x52	/* Pin "BRDY0" Buffer Depth Register */
#define W5300_P1_BRDYR		0x54	/* Pin "BRDY1" Configuration Register */
#define W5300_P1_BDPTHR		0x56	/* Pin "BRDY1" Buffer Depth Register */
#define W5300_P2_BRDYR		0x58	/* Pin "BRDY2" Configuration Register */
#define W5300_P2_BDPTHR		0x5A	/* Pin "BRDY2" Buffer Depth Register */
#define W5300_P3_BRDYR		0x5C	/* Pin "BRDY3" Configuration Register */
#define W5300_P3_BDPTHR		0x5E	/* Pin "BRDY3" Buffer Depth Register */

#define W5300_IDR			0xFE	/* W5300 ID Register */

/* SOCKET related register */
#define SOCKET_REG_START		0x0200
#define SOCKET_REG_SIZE			0x0040

#define W5300_Sn_MR(n)			(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x00)	/* SOCKETn Mode Register */
#define W5300_Sn_CR(n)			(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x02)	/* SOCKETn Command Register */
#define W5300_Sn_IMR(n)			(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x04)	/* SOCKETn Interrupt Mask Register */
#define W5300_Sn_IR(n)			(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x06)	/* SOCKETn Interrupt Register */
#define W5300_Sn_SSR(n)			(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x08)	/* SOCKETn Socket Status Register */
#define W5300_Sn_PORTR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x0A)	/* SOCKETn Source Port Register */
#define W5300_Sn_DHAR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x0C)	/* SOCKETn Destination Hardware Address Register (0,1) */
#define W5300_Sn_DHAR2(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x0E)	/* SOCKETn Destination Hardware Address Register (2,3) */
#define W5300_Sn_DHAR4(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x10)	/* SOCKETn Destination Hardware Address Register (4,5) */
#define W5300_Sn_DPORTR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x12)	/* SOCKETn Destination Port Register */
#define W5300_Sn_DIPR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x14)	/* SOCKETn Destination IP Address Register (0,1) */
#define W5300_Sn_DIPR2(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x16)	/* SOCKETn Destination IP Address Register (2,3) */
#define W5300_Sn_MSSR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x18)	/* SOCKETn Maximum Segment Size Register */
#define W5300_Sn_PROTOR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x1A)	/* SOCKETn Protocol Number Register */
#define W5300_Sn_TOSR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x1C)	/* SOCKETn TOS Register (Type Of Service) */
#define W5300_Sn_TTLR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x1E)	/* SOCKETn TTL Register (Time To Live) */
#define W5300_Sn_TX_WRSR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x20)	/* SOCKETn TX Write Size Register (0,1) */
#define W5300_Sn_TX_WRSR2(n)	(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x22)	/* SOCKETn TX Write Size Register (2,3) */
#define W5300_Sn_TX_FSR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x24)	/* SOCKETn TX Free Size Register (0,1) */
#define W5300_Sn_TX_FSR2(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x26)	/* SOCKETn TX Free Size Register (2,3) */
#define W5300_Sn_RX_RSR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x28)	/* SOCKETn RX Receive Size Register (0,1) */
#define W5300_Sn_RX_RSR2(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x2A)	/* SOCKETn RX Receive Size Register (2,3) */
#define W5300_Sn_FRAGR(n)		(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x2C)	/* SOCKETn Fragment Register */
#define W5300_Sn_TX_FIFOR(n)	(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x2E)	/* SOCKETn TX FIFO Register */
#define W5300_Sn_RX_FIFOR(n)	(SOCKET_REG_START + (n) * SOCKET_REG_SIZE + 0x30)	/* SOCKETn RX FIFO Register */



/* bits in Mode Register */
#define W5300_MR_DBW		(1u << 15)	/* Data Bus Width (0 = 8, 1 = 16 bit) */
#define W5300_MR_MPF		(1u << 14)	/* MAC Layer Pause Frame */
#define W5300_MR_WDF		(7u << 11)	/* Write Data Fetch Time */
#define W5300_MR_RDH		(1u << 10)	/* Read Data Hold Time */
#define W5300_MR_FS			(1u <<  8)	/* FIFO Swap Bit */
#define W5300_MR_RST		(1u <<  7)	/* S/W Reset */
#define W5300_MR_MT			(1u <<  5)	/* Memory Test Bit */
#define W5300_MR_PB			(1u <<  4)	/* Ping Block Mode */
#define W5300_MR_PPPOE		(1u <<  3)	/* PPPoE Mode */
#define W5300_MR_DBS		(1u <<  2)	/* Data Bus Swap */
#define W5300_MR_IND		(1u <<  0)	/* Indirect Bus I/F Mode */

/* bits in Interrupt (Mask) Register */
#define W5300_IR_IPCF		(1u << 15)	/* IP Conflict */
#define W5300_IR_DPUR		(1u << 14)	/* Destination Port unreachable */
#define W5300_IR_PPPT		(1u << 13)	/* PPPoE Terminate */
#define W5300_IR_FMTU		(1u << 12)	/* Fragment MTU */
#define W5300_IR_SINT(n)	(1u << (n))	/* SOCKETn Interrupt */

/* bits in SOCKET Mode Register */
#define W5300_SnMR_ALIGN	(1u <<  8)	/* Alignment bit */
#define W5300_SnMR_MULTI	(1u <<  7)	/* Multicasting bit */
#define W5300_SnMR_MF		(1u <<  6)	/* MAC Filter */
#define W5300_SnMR_ND		(1u <<  5)	/* Use No Delayed ACK */
#define W5300_SnMR_PT_MSK	(15 <<  0)	/* Protocol type field */
#define W5300_SnMR_CLOSE	( 0 <<  0)	/* Protocol: none (Closed) */
#define W5300_SnMR_TCP		( 1 <<  0)	/* Protocol: TCP */
#define W5300_SnMR_UDP		( 2 <<  0)	/* Protocol: UDP */
#define W5300_SnMR_IPRAW	( 3 <<  0)	/* Protocol: IPRAW */
#define W5300_SnMR_MACRAW	( 4 <<  0)	/* Protocol: MACRAW (only SOCKET0) */
#define W5300_SnMR_PPPOE	( 5 <<  0)	/* Protocol: PPPoE (only SOCKET0) */

/* SOCKET Command Register values */
#define W5300_SnCR_OPEN			(0x01)	/* Open and initialise socket */
#define W5300_SnCR_LISTEN		(0x02)	/* wait for connection (TCP) */
#define W5300_SnCR_CONNECT		(0x04)	/* send connection request (TCP) */
#define W5300_SnCR_DISCON		(0x08)	/* send closing request (TCP) */
#define W5300_SnCR_CLOSE		(0x10)	/* Close socket */
#define W5300_SnCR_SEND			(0x20)	/* Send data */
#define W5300_SnCR_SEND_MAC		(0x21)	/* Send data with MAC address */
#define W5300_SnCR_SEND_KEEP	(0x22)	/* Send keep alive message */
#define W5300_SnCR_RECV			(0x40)	/* Received data (signal end of receive) */

/* bits in SOCKETn Interrupt (Mask) Register */
#define W5300_SnIR_PRECV	(1u <<  7)	/* PPP Receive Interrupt */
#define W5300_SnIR_PFAIL	(1u <<  6)	/* PPP Fail Interrupt */
#define W5300_SnIR_PNEXT	(1u <<  5)	/* PPP Next Phase Interrupt */
#define W5300_SnIR_SENDOK	(1u <<  4)	/* Send OK Interrupt */
#define W5300_SnIR_TIMEOUT	(1u <<  3)	/* Timeout Interrupt */
#define W5300_SnIR_RECV		(1u <<  2)	/* Receive Interrupt */
#define W5300_SnIR_DISCON	(1u <<  1)	/* Disconnect Interrupt */
#define W5300_SnIR_CON		(1u <<  0)	/* Connect Interrupt */

/* SOCKET Status Register values */
#define W5300_SOCK_CLOSED		(0x00)	/* closed */
#define W5300_SOCK_ARP			(0x01)	/* connect phase */
#define W5300_SOCK_INIT			(0x13)	/* init state (TCP) */
#define W5300_SOCK_LISTEN		(0x14)	/* listen state (TCP) */
#define W5300_SOCK_SYNSEND		(0x15)	/* connection phase (TCP) */
#define W5300_SOCK_SYNRECV		(0x16)	/* connection phase (TCP) */
#define W5300_SOCK_ESTABLISHED	(0x17)	/* success to connect (TCP) */
#define W5300_SOCK_FIN_WAIT		(0x18)	/* closing phase (TCP) */
#define W5300_SOCK_TIME_WAIT	(0x1B)	/* closing phase (TCP) */
#define W5300_SOCK_CLOSE_WAIT	(0x1C)	/* closing phase (TCP) */
#define W5300_SOCK_LAST_ACK		(0x1D)	/* closing phase (TCP) */
#define W5300_SOCK_UDP			(0x22)	/* open in UDP mode */
#define W5300_SOCK_IPRAW		(0x32)	/* open in IPRAW mode */
#define W5300_SOCK_MACRAW		(0x42)	/* open in MACRAW mode */
#define W5300_SOCK_PPPOE		(0x5F)	/* open in PPPoE mode */




int lanw5300_init(unsigned int eth_base, unsigned char *eth_mac);
int lanw5300_poll(void);
int lanw5300_can_send(void);
int lanw5300_send(const char *buf, int len);
int lanw5300_read(char *buf, int bufsize);


#endif /* __WIZNET_LANW5300_H__ */
